/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
Freescale Confidential Proprietary
\file       app_MirrorSlaveCtrl.c
\brief      Functions for mirror controller (LIN slave)
\author     Freescale Semiconductor
\author     B05114
\version    0.1
\date       October/2007
*/
/*******************************************************************************/

/** Variable types and common macros */
#include "typedefs.h"

/** GPIO-based SPI driver definitions and function prototypes */
#include "lle_GPIO.h"

#include <linapi.h>

#include "app_MirrorSlaveCtrl.h"

#include "des_MC33972.h"

UINT8 u8LINMsgSent[2];       /* Transmit data */
//UINT8 MsgRcvd [2];      /* received data */


LINStatusType   u8ret;

// Analog values variables      
extern UINT16  fm_analog1, fm_analog2, fm_analog5;


/*******************************************************************************/
/**
* \brief    Send LIN command
* \author   B05114
* \param    u8ID
* \return   void
*/
void Send_LIN_Command(UINT8 u8LIN_ID)
{     
    LED1 ^= 1;       /* Toggle indicator */
    
    u8ret = LIN_PutMsg(u8LIN_ID, u8LINMsgSent);   /* Write message */ 
    
    u8ret = LIN_RequestMsg(u8LIN_ID);  /* Send a request for message */
    
        do      
        {
            u8ret = LIN_DriverStatus();
        }
        while(u8ret & LIN_STATUS_PENDING);  /* Wait for message processing */

    
    u8ret = LIN_MsgStatus(u8LIN_ID);   /* Check received message status */
        
        //if (ret == LIN_OK)		        
            //ret = LIN_GetMsg(u8LIN_ID, MsgRcvd); /* Read message */
}		


/*******************************************************************************/		
/**
* \brief    LIN slave/ mirror control
* \author   B05114
* \param    none
* \return   void
*/
void app_Mirror_Control(void)
{                               /* Compare with analog value previously read */
    if(fm_analog5 == S3_ON)     /* to determine if push-button S1 was pressed */
    {
        u8LINMsgSent[0] = LIGHT_COMM;      /* Update command for LIN frame */
        u8LINMsgSent[1] = MIRROR_LIGHT;        
    }


    /* Determine if knob I was turned to left */
	if(fm_analog1 <= UP_THR )       
    {
    u8LINMsgSent[0] = MOVE_COMM;
    u8LINMsgSent[1] = MIRROR_UP;   
    }
	
	else
	{	/* Determine if knob I was turned to right */     	
    	if(fm_analog1 >= DOWN_THR )    
        {
        u8LINMsgSent[0] = MOVE_COMM;
        u8LINMsgSent[1] = MIRROR_DOWN; 
        }
        
    	else
	    {   /* Determine if knob II was turned to left */ 	
        	if(fm_analog2 <= LEFT_THR )    
            {
            u8LINMsgSent[0] = MOVE_COMM;
            u8LINMsgSent[1] = MIRROR_LEFT;
            }
            
        	else
	        {   /* Determine if knob II was turned to right */     	
            	if(fm_analog2 >= RIGHT_THR )       
                {
                u8LINMsgSent[0] = MOVE_COMM;
                u8LINMsgSent[1] = MIRROR_RIGHT;                             
                }
            }
	    }
	}
	
	
	if(u8LINMsgSent[0] != NO_COMM)      /* If frame has been updated */
	{	    
	    Send_LIN_Command(MIRROR_ID);
	    u8LINMsgSent[0] = NO_COMM;      /* send LIN message */ 
	}
}

/*******************************************************************************/		

