/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
Freescale Confidential Proprietary
\file       app_WindowSlaveCtrl.c
\brief      Functions for window-lift controller (LIN slave)
\author     Freescale Semiconductor
\author     B05114
\version    0.1
\date       October/2007
*/
/*******************************************************************************/

/** Variable types and common macros */
#include "typedefs.h"

/** GPIO-based SPI driver definitions and function prototypes */
#include "lle_GPIO.h"

#include <linapi.h>

#include "app_WindowSlaveCtrl.h"

#include "des_MC33972.h"

UINT8 u8LIN_WMsgSent[5];       /* Transmit data */
//UINT8 MsgRcvd [2];      /* received data */


LINStatusType   Wret;

// Analog values variables      
extern UINT16  fm_analog1, fm_analog2, fm_analog5;


/*******************************************************************************/
/**
* \brief    Send LIN command
* \author   B05114
* \param    u8ID
* \return   void
*/
void Send_LIN_WCommand(UINT8 u8LIN_ID)
{     
    LED1 ^= 1;       /* Toggle indicator */
    
    Wret = LIN_PutMsg(u8LIN_ID, u8LIN_WMsgSent);     /* Write message */  
    
    Wret = LIN_RequestMsg(u8LIN_ID);  /* Send a request for message */
    
        do      
        {
            Wret = LIN_DriverStatus();
        }
        while(Wret & LIN_STATUS_PENDING);  /* Wait for message processing */

    
    Wret = LIN_MsgStatus(u8LIN_ID);   /* Check received message status */
        
        //if (ret == LIN_OK)		        
            //ret = LIN_GetMsg(u8LIN_ID, MsgRcvd); /* Read message */
}		


/*******************************************************************************/		
/**
* \brief    LIN slave/ window control
* \author   B05114
* \param    none
* \return   void
*/
void app_Window_Control(void)
{                               /* Compare with analog value previously read */
    if(fm_analog5 == S1_ON)     /* to determine if push-button S1 was pressed */
    {
        u8LIN_WMsgSent[0] = WINDOW_UP; /* Fill LIN frame */
        u8LIN_WMsgSent[1] = 0x55;      /* Slave requires 4 byte  messages */
        u8LIN_WMsgSent[2] = 0x55;
        u8LIN_WMsgSent[3] = 0x55;        
    } 
    
    
    else if(fm_analog5 == S2_ON)    /* Determine if push-button S1 was pressed */    
    {
        u8LIN_WMsgSent[0] = WINDOW_DOWN;
        u8LIN_WMsgSent[1] = 0xAA;       
        u8LIN_WMsgSent[2] = 0xAA;
        u8LIN_WMsgSent[3] = 0xAA;                
    }    
    
    
    else if(fm_analog5 == 0)        /* Determine if no push-button was pressed */    
    {    
        if(u8LIN_WMsgSent[0] != WINDOW_STOP)    /* Don't send stop command more than once */
        {            
            u8LIN_WMsgSent[0] = WINDOW_STOP;
            u8LIN_WMsgSent[1] = 0x5A;      
            u8LIN_WMsgSent[2] = 0x5A;
            u8LIN_WMsgSent[3] = 0x5A;           
        }
    }  
    
    
    if(u8LIN_WMsgSent[3] != NO_WOP)       /* If frame has been updated */
	{	    
	    Send_LIN_WCommand(WINDLIFT_ID);    /* send LIN message */ 
	    u8LIN_WMsgSent[3] = NO_WOP;
	}              
}

/*******************************************************************************/