/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
\file       app_boardAnalogVal.c
\brief      Convert MSDI Board analog values
\author     Freescale Semiconductor
\author     RC574C/ B05114
\version    0.2
\date       October/2007
*/
/*******************************************************************************/

#include "app_boardAnalogVal.h"
#include "des_MC33972.h"
#include "lle_ADC.h"
#include "lle_TIME.h"
#include "lle_GPIO.h"

// FreeMASTER analog values variables      
extern UINT16  fm_analog1, fm_analog2, fm_analog3, fm_analog4, fm_analog5; 
extern UINT16 msdiISpTrist, msdiISgTrist;

/*******************************************************************************/
/**
* \brief    Convert MSDI Board II analog values (voltage1/2,
            Light/Temperature sensor, pushbuttons)
* \author   rc574c
* \param    none
* \return   void
*/
void app_boardMSDIAnalogVal(void)
{
	UINT16 analogVal;
	
	DISABLE_INTERRUPTS();
	
	// Analog Voltage I
	// Select AMUX channel SP2 
	des_MC33972_Set_Analog_Channel(MSDI_I, MSDI_AN_SP2, MSDI_AN_HiImpedance);
	// Wait 100us for analog voltage settle
  	lle_Delay100us();
	// Run ATD to convert value  
	fm_analog1 = lle_ADC(AMUX_MC33972_I);
	
	
	// Analog Voltage II
	// Select AMUX channel SP3 
	des_MC33972_Set_Analog_Channel(MSDI_I, MSDI_AN_SP3, MSDI_AN_HiImpedance); 
	// Wait 100us for analog voltage settle
	lle_Delay100us();
	// Run ATD to convert value 
	fm_analog2 = lle_ADC(AMUX_MC33972_I);


	// Temperature sensor
	// Select AMUX channel SP1 
	des_MC33972_Set_Analog_Channel(MSDI_I, MSDI_AN_SP1, MSDI_AN_HiImpedance);	 
	// Wait 100us for analog voltage settle
	lle_Delay100us();
	// Run ATD to convert value 
	fm_analog3 = lle_ADC(AMUX_MC33972_I);
	
	
	// Visible Light sensor
	// Select AMUX channel SP4 
	des_MC33972_Set_Analog_Channel(MSDI_I, MSDI_AN_SP4, MSDI_AN_HiImpedance); 
	// Wait 100us for analog voltage settle
	lle_Delay100us();
	// Run ATD to convert value 
    fm_analog4 = lle_ADC(AMUX_MC33972_I);
	
	
	// MSDI board II pushbuttons
	// Select AMUX channel SP0 
	des_MC33972_Set_Analog_Channel(MSDI_I, MSDI_AN_SP0, MSDI_AN_HiImpedance); 
	// Wait 100us for analog voltage settle
	lle_Delay100us();
	// Run ATD to convert value 	
	analogVal = lle_ADC(AMUX_MC33972_I);
	
	// Select pushbutton
	if (analogVal > PB1_THR)
	{
		fm_analog5 = 1;   /* Update command */
		
		/* Turn on S1 LED on analog stimulus board */
		msdiISpTrist = msdiISpTrist & ~MSDI_SP7;    
		des_MC33972_Set_SP_HighImpedance(MSDI_I, msdiISpTrist);
		
	}
  	else if ((PB1_THR > analogVal) && (analogVal > PB2_THR))
	{
		fm_analog5 = 2;
		
		/* Turn on S2 LED on analog stimulus board */
		msdiISpTrist = msdiISpTrist & ~MSDI_SP6;    
		des_MC33972_Set_SP_HighImpedance(MSDI_I, msdiISpTrist);
	} 
	else if ((PB2_THR > analogVal) && (analogVal > PB3_THR))
	{
		fm_analog5 = 3;
		
		/* Turn on S3 LED on analog stimulus board */
		msdiISpTrist = msdiISpTrist & ~MSDI_SP5;    
		des_MC33972_Set_SP_HighImpedance(MSDI_I, msdiISpTrist);
	}  
	else
  	{
		fm_analog5 = 0;
		
		/* Turn off LEDs on push-buttons in analog board */
    	msdiISpTrist = msdiISpTrist | MSDI_SP5| MSDI_SP6| MSDI_SP7;
		des_MC33972_Set_SP_HighImpedance(MSDI_I, msdiISpTrist);
	}       
	
	ENABLE_INTERRUPTS();
}

/*******************************************************************************/
/**
* \brief    Convert MSDI Board analog values
* \author   rc574c
* \param    none
* \return   void
*/
void app_boardAnalogVal(void)
{
	app_boardMSDIAnalogVal();	
}

/*******************************************************************************/