/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
\file       app_boardDevCtrl.c
\brief      APD devices control 
\author     Freescale Semiconductor
\author     rc574c
\version    0.1
\date       May/2007
*/
/*******************************************************************************/

#include "app_boardDevCtrl.h"
#include "main.h"
#include "lle_GPIO.h"
#include "des_MC33972.h"
#include "des_MC33887.h"
#include "des_MC33742.h"
#include "des_MC33879.h"
#include "des_MC15XS3400.h"
#include "des_MC35XS3400.h"
#include "des_MC10XS3412.h"

// FreeMASTER control variables 
extern UINT8  fm_status, fm_task, fm_action0, fm_action1, fm_action2, fm_action3,
              fm_action4, fm_action5, fm_action6, fm_action7, fm_action8, fm_action9,
              fm_action10, fm_action11, fm_action12, fm_action13, fm_action14, fm_action15;

// eSwitch pwm control selection
extern UINT8   pwm1, pwm2, pwmCtr1, pwmCtr2, pwmCtr3;

// Door lock status
UINT8 lockStatus;

// MC33972 MSDI tristate SP/SG cmd 
UINT16 msdiISpTrist, msdiISgTrist;

/*******************************************************************************/
/**
* \brief    Main board ADP devices watchdogs update  
* \author   rc574c
* \param    none
* \return   void
*/
void app_boardWatchdogUpd(void)
{
    // Clear MC33742 watchdog?
	if (fm_action13 != WD_TIMEOUT)
	{
		// Clear MC33742 watchdog
		des_MC33742_ClearWDT();
	}
  
	// MC15XS3400, MC35XS3400, MC10XS3412 watchdogs toggled, when control command was sent.
}

/*******************************************************************************/
/**
* \brief    Brake LED light turn ON - MC15XS3400 HS0 ON 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightBrakeON(void)
{
	des_MC15XS3400_HS_Control(XS_HS0, XS_ON, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    Brake LED light turn OFF - MC15XS3400 HS0 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightBrakeOFF(void)
{
	des_MC15XS3400_HS_Control(XS_HS0, XS_OFF, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    Cabin lights turn ON - MC15XS3400 HS1,HS2 ON 
* \author   rc574c
* \param    none
* \return   void
*/	
void app_lightCabinON(void)
{
	if (pwmCtr3)
	{
		// Cabin Lightning PWM controlled by Analog Voltage 2 (MSDI Board II)
		des_MC15XS3400_HS_Control(XS_HS1, XS_ON, pwm2);
		des_MC15XS3400_HS_Control(XS_HS2, XS_ON, pwm2);
	}
	else
	{		
		// Cabin Lightning PWM set to default value
		des_MC15XS3400_HS_Control(XS_HS1, XS_ON, PWM_DEFAULT);
		des_MC15XS3400_HS_Control(XS_HS2, XS_ON, PWM_DEFAULT);		
	}
}

/*******************************************************************************/
/**
* \brief    Cabin lights turn OFF - MC15XS3400 HS1,HS2 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightCabinOFF(void)
{
	des_MC15XS3400_HS_Control(XS_HS1, XS_OFF, PWM_DEFAULT);
	des_MC15XS3400_HS_Control(XS_HS2, XS_OFF, PWM_DEFAULT);
}

/*******************************************************************************/
/**
* \brief    Turn lights turn ON - MC35XS3400 HS0,HS1 ON 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightTurnON(void)
{
	if (pwmCtr1)
	{	
		// Turn Lightning PWM controlled by Analog Voltage 2 (MSDI Board II)
		des_MC35XS3400_HS_Control(XS_HS0, XS_ON, pwm2);
		des_MC35XS3400_HS_Control(XS_HS1, XS_ON, pwm2);
	}
	else
	{
		// Turn Lightning PWM set to default value
		des_MC35XS3400_HS_Control(XS_HS0, XS_ON, PWM_DEFAULT);
		des_MC35XS3400_HS_Control(XS_HS1, XS_ON, PWM_DEFAULT);	
	}
}

/*******************************************************************************/
/**
* \brief    Turn lights turn OFF - MC35XS3400 HS0,HS1 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightTurnOFF(void)
{
	des_MC35XS3400_HS_Control(XS_HS0, XS_OFF, PWM_DEFAULT);
	des_MC35XS3400_HS_Control(XS_HS1, XS_OFF, PWM_DEFAULT);
}

/*******************************************************************************/
/**
* \brief    Rear lights turn ON - MC35XS3400 HS2,HS3 ON 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightRearON(void)
{
	if (pwmCtr2)
	{	
		// Rear Lightning PWM controlled by Analog Voltage 2 (MSDI Board II)
		des_MC35XS3400_HS_Control(XS_HS2, XS_ON, pwm2);
		des_MC35XS3400_HS_Control(XS_HS3, XS_ON, pwm2);
	}
	else
	{	
		// Rear Lightning PWM set to default value
		des_MC35XS3400_HS_Control(XS_HS2, XS_ON, PWM_DEFAULT);
		des_MC35XS3400_HS_Control(XS_HS3, XS_ON, PWM_DEFAULT);	
	}
}

/*******************************************************************************/
/**
* \brief    Rear lights turn OFF - MC35XS3400 HS2,HS3 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightRearOFF(void)
{
	des_MC35XS3400_HS_Control(XS_HS2, XS_OFF, PWM_DEFAULT);
	des_MC35XS3400_HS_Control(XS_HS3, XS_OFF, PWM_DEFAULT);
}

/*******************************************************************************/
/**
* \brief    55W lights turn ON - MC10XS3412 HS0,HS1 ON 
* \author   rc574c
* \param    none
* \return   void
*/
void app_light55WON(void)
{
	des_MC10XS3412_HS_Control(XS_HS0, XS_ON, PWM_MAX);
	des_MC10XS3412_HS_Control(XS_HS1, XS_ON, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    55W lights turn OFF - MC10XS3412 HS0,HS1 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_light55WOFF(void)
{
	des_MC10XS3412_HS_Control(XS_HS0, XS_OFF, PWM_MAX);
	des_MC10XS3412_HS_Control(XS_HS1, XS_OFF, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    Washer pump turn ON - MC10XS3412 HS2 ON 
* \author   rc574c
* \param    none
* \return   void
*/
void app_washerPumpON(void)
{
	des_MC10XS3412_HS_Control(XS_HS2, XS_ON, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    Washer pump turn OFF - MC10XS3412 HS2 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_washerPumpOFF(void)
{
	des_MC10XS3412_HS_Control(XS_HS2, XS_OFF, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    Imobilizer LED light turn ON - MC10XS3412 HS3 ON 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightImobON(void)
{
	des_MC10XS3412_HS_Control(XS_HS3, XS_ON, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    Imobilizer LED light turn OFF - MC10XS3412 HS3 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightImobOFF(void)
{
	des_MC10XS3412_HS_Control(XS_HS3, XS_OFF, PWM_MAX);
}

/*******************************************************************************/
/**
* \brief    Door lock CLOSE.
            First function call - MC33887 IN1 ON, IN2 OFF 
            Second function call - MC33887 IN1 OFF, IN2 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_doorLockCLOSE(void)
{
	if (lockStatus == UNLOCKED)
	{
    	des_MC33887_IN1_H_IN2_L();
	}
	else
	{
 		des_MC33887_IN1_L_IN2_L();
	}

	lockStatus = LOCKED;
}

/*******************************************************************************/
/**
* \brief    Door lock OPEN.
            First function call - MC33887 IN1 OFF, IN2 ON 
            Second function call - MC33887 IN1 OFF, IN2 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_doorLockOPEN(void)
{
	if (lockStatus == LOCKED)
	{
		des_MC33887_IN1_L_IN2_H();
	}
	else
	{
		des_MC33887_IN1_L_IN2_L();
	}

	lockStatus = UNLOCKED;
} 

/*******************************************************************************/
/**
* \brief    Interior LED lights turn ON - MC33879 IN6 ON/PWM 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightInteriorON(void)
{
	// Apply PWM defined by Analog Voltage 1 (MSDI Board II)
	des_MC33879_Output_Control(COSS_OUT6,OFF);		
}

/*******************************************************************************/
/**
* \brief    Interior LED lights turn OFF - MC33879 IN6 OFF 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightInteriorOFF(void)
{
	// Load 0x00 to PWM 8-bit module
	des_MC33879_Output_Control(COSS_OUT6,OFF);	
}

/*******************************************************************************/
/**
* \brief    Dashboard LED lights turn ON 
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightDashboardON(void)
{
	// MSDI analog board blue LEDs ON (SG0, SG1, SG1, SG3)
	msdiISgTrist = msdiISgTrist & ((~MSDI_SG0) & (~MSDI_SG1) & (~MSDI_SG2) & (~MSDI_SG3));
	des_MC33972_Set_SG_HighImpedance(MSDI_I, msdiISgTrist);	
}

/*******************************************************************************/
/**
* \brief    Dashboard LED lights turn OFF
* \author   rc574c
* \param    none
* \return   void
*/
void app_lightDashboardOFF(void)
{
	// MSDI analog board blue LEDs OFF (SG0, SG1, SG2, SG3)
	msdiISgTrist = msdiISgTrist | (MSDI_SG0 | MSDI_SG1 | MSDI_SG2 | MSDI_SG3);
	des_MC33972_Set_SG_HighImpedance(MSDI_I, msdiISgTrist);
}

/*******************************************************************************/
