/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
\file       app_boardInit.c
\brief      Initialize main board devices  
\author     Freescale Semiconductor
\author     rc574c
\version    0.1
\date       May/2007
*/
/*******************************************************************************/

/** Derivative peripheral declarations */
#include "derivative.h"

#include "app_boardInit.h"
#include "des_MC33661.h"
#include "des_MC33742.h"
#include "des_MC33972.h"
#include "des_MC33887.h"
#include "des_MC33879.h"
#include "des_MC15XS3400.h"
#include "des_MC35XS3400.h"
#include "des_MC10XS3412.h"
#include "lle_GPIO.h"
#include "lle_TIME.h"
#include "lle_ADC.h"
#include "lle_GPIO_SPI.h" 


/*******************************************************************************/
/**
* \brief    Init MCU peripherals
* \author   rc574c
* \param    none
* \return   void
*/                        
void app_initMCUPeriph(void)
{         
    SOPT1_COPT = 0;     /* Watchdog disabled */
    
    /* Generate 10ms delay to ensure, that board power supply is in limits */
	lle_Delay10ms();
    
    lle_MCG_Init();     /* Clock Generator initialization */

    lle_Init_RTC();     /* Initialise RTC */
      
    lle_SetupPINS();    /* GPIO initialization */
    
    lle_GPIO_SPI_Init();    /* GPIO based SPI initialization */  
      
    lle_Init_ADC();     /* Analog to digital converter initialization */
 
    (void)FlashInit();   	
}


/*******************************************************************************/
/**
* \brief    Initialize main board devices 
* \author   rc574c
* \param    none
* \return   void
*/
void app_initAPDDevices(void)
{		
	/* Generate delay (3.4ms at least) to ensure, that MC33742 is in 
	   the normal request mode */
	lle_Delay4ms();
	
  	// MC33742 - CAN SBC 
	des_MC33742_SetMode(SBC_NORMAL);
  
    //des_MC33742_SetDebugMode();
	
	// MC33742 config   	
    des_MC33742_Config();         		           
    	
    // MC33661 - LIN2, LIN3, LIN4, LIN5 in normal mode
    des_MC33661_SetMode(LIN_NORMAL);
     	
	// MC15XS3400 - eSwitch 
	des_MC15XS3400_SetMode(XS_NORMAL);
	des_MC15XS3400_Config();
		
	// MC35XS3400 - eSwitch
	des_MC35XS3400_SetMode(XS_NORMAL);
	des_MC35XS3400_Config(); 

	// MC10XS3412 - eSwitch
	des_MC10XS3412_SetMode(XS_NORMAL);
	des_MC10XS3412_Config(); 

	// MC33879 - COSS Lite 
	des_MC33879_SetMode(COSS_NORMAL);
	des_MC33879_Config();
	
  	// MC33972 I - MSDI -> MSDI Board I connected - pushbuttons
    des_MC33972_Config(MSDI_I);
    
    // MC33972 II - MSDI -> MSDI Board II connected - analog voltage sources
    //des_MC33972_Config(MSDI_II);

    // MC33887 - Door Lock H-bridge
    des_MC33887_Config();    
}
