/******************************************************************************
*
* Freescale Semiconductor Inc.
* (c) Copyright 2004-2005 Freescale Semiconductor, Inc.
* ALL RIGHTS RESERVED.
*
***************************************************************************//*!
*
* @file     echo.h
*
* @author   RC574C
*
* @version  1.0.1.0
*
* @date     Oct-12-2006
*
* @brief    This file contains Echo software header file for MC9S12XDP512.
*           Based on Echo software driver for HCS08.
* 
* @note     Compiler CodeWarrior HCS12X V4.5
*
******************************************************************************/

#ifndef _ECHO_H
#define _ECHO_H


/******************************************************************************
* This section defines some symbols for use below. DO NOT EDIT!			      
******************************************************************************/
#define ECHO_FSK	1
#define ECHO_OOK	0                                                        
#define ECHO_F304MHz    0
#define ECHO_F315MHz	1
#define ECHO_F434MHz	2
#define ECHO_F868MHz	3
#define ECHO_F916MHz	4
/*****************************************************************************/
                                                                                
/******************************************************************************
* THIS SECTION CONTAINS VALUES YOU MUST DEFINE!				     
******************************************************************************/
//#include <mc9s12xdp512.h>                   /* Derivative information        */
//#include "9S12XDP512.h"                            /* derivative information */

/******************************************************************************
* Rx message buffer							      
******************************************************************************/

extern unsigned char echoRxBuffer[];

/******************************************************************************
* Define required pins							      
******************************************************************************/
#define ECHO_CONFB				PTT_PTT4	/* Define pin used for CONFB     */
#define ECHO_CONFB_DDR			DDRT_DDRT4

#define ECHO_SEB				PORTC_PC6	/* Define pin used for SEB		 */
#define ECHO_SEB_DDR			DDRC_DDRC6

// #define ECHO_RSSIC			PORTC_PC7	/* Define pin used for RSSIC     */
// #define ECHO_RSSIC_DDR		DDRC_DDRC7  /* Comment in case of ECHO's	 */
											/* RSSIC pin tight to ground or  */
											/* disconnected from MCU		 */

/******************************************************************************
* Setup SPI                                                                 
******************************************************************************/
#define ECHO_SPI_ADDRESS		0x00F0		/* Location of SPI registers     */
																						
#define ECHO_SPI_CLOCK_SPEED	24000000	/* SPI clock speed		         */


/******************************************************************************
* Buffering parameters                         
******************************************************************************/
#define ECHO_MAX_DATA_SIZE		6	/* Max length of data field in msg	 	 */

#define ECHO_RX_BUF_COUNT		4	/* Number of Rx buffers to allocate   	 */
									/* An additional buffer is allocated	 */
									/* for internal use by the driver		 */
									/* Note: each buffer consumes			 */
									/* ECHO_MAX_DATA_SIZE+2 bytes in memory! */

/******************************************************************************
* Echo modulation parameters                       
******************************************************************************/
#define ECHO_MODE_VALUE		ECHO_FSK    	/* ECHO_OOK = OOK reception		 */
											/* ECHO_FSK = FSK reception		 */
#define ECHO_MODE_OOKREF	1	    /* Select the data slicer reference in	 */
									/* OOK mode: 0 = fixed, 1 = adaptive 	 */
									/* Can delete/ignore if using FSK	 	 */
												
#define ECHO_BAND_VALUE		ECHO_F434MHz	/* ECHO_F304MHz, ECHO_F315MHz,	 */
											/* ECHO_F434MHz, ECHO_F868MHz,	 */
											/* or ECHO_F916MHz				 */

#define ECHO_DATA_RATE	  	19200			/* Set Echo data rate in Hz		 */
											/* (before Manchester encoding)	 */

/******************************************************************************
* ID and Header set up
******************************************************************************/
#define ECHO_ID_LENGTH		6			/* Length of ID (2,4,5,6 or 8 bits)	 */
#define ECHO_ID_VALUE		0x11		/* ID word recognised by Echo		 */

#define ECHO_HEADER_LENGTH	6		/* Length of header (1,2,4,6 bits)	 	 */
#define ECHO_HEADER_VALUE	0x26	/* Header word recognised by Echo	 	 */
									/* (must not be present in Preamble/ID)	 */

/******************************************************************************
* Receive mode On/off control
******************************************************************************/
#define ECHO_SOE_VALUE		1			/* 0 = strobe oscillator disabled	 */
										/* 1 = strobe oscillator enabled	 */

/* These values are calculated from the Echo datasheet						 */
#define ECHO_RXON_VALUE		15							/* On time:  1->15	 */
#define ECHO_RXOFF_VALUE	0							/* Off time: 0->7	 */

/******************************************************************************
* Timer set up
******************************************************************************/
#define ECHO_TIMER_ADDRESS	0x0040		/* Location of 1st timer register	 */
#define ECHO_TIMER_CHANNEL	0			/* Define which timer channel to use */
										/* Note:timer channels start from 0	 */
										/* Use only 0-6, channel 7 reserved	 */
										/* for main counter reset			 */

/* #define ECHO_TIMER_CLOCK_SOURCE	1*/ /* Use to set clock source for timer */
										/* 1 = Bus clock					 */
										/* 2 = XCLK (if available)			 */							
										/* 3 = Ext clock					 */

#define ECHO_USE_DATACLK	0		/* Indicate if the Ext clock is DATACLK	 */
									/* output from Echo. If using DATACLK	 */
									/* and ECHO_TIMER_CLOCK_SOURCE = 3,		 */
									/* ECHO_TIMER_CLOCK_SPEED is replaced	 */
									/* with Fdataclk calculated instead.	 */
									/* 0 = dataclock not enabled			 */
									/* 1 = dataclock enabled				 */

#define ECHO_TIMER_CLOCK_SPEED	24000000	/* Set timer clock speed in Hz	 */

#define ECHO_TIMER_PRESCALE		1			/* Specify timer prescaler value */

#define ECHO_TIMER_DISABLE		1	/* Allows driver to turn off timer after */
									/* use. Delete this #define if you want  */
									/* timer to stay on						 */

#define ECHO_CRYSTAL_FREQUENCY	24000000		/* Crystal frequency (in Hz) */
												/* Typical values used		 */
												/* RF Output				 */ 
												/* 315MHz  - 17581400		 */
												/* 434MHz  - 24190660		 */
												/* 868MHz  - 24161390		 */

/******************************************************************************
* RSSI set up
******************************************************************************/
#define ECHO_USE_MCU_ATD	0   		/* Enable the use of an MCU ATD to	 */
										/* convert analogue RSSI readings.	 */
										/* If this is not enabled, only		 */
										/* digital RSSI will be available.	 */
										/* 0 = Analogue not available		 */
										/* 1 = Use an MCU ATD for analogue	 */

#define ECHO_ATD            0       	/* Select MCU ATD					 */
                                    	/* 0 = ATD0 (8-channel)				 */
                                    	/* 1 = ATD1 (16-channel)			 */
                                    	
#define ECHO_ATD_ADDRESS	0x02C0  /* Location of the first ATD0/ATD1 reg.	 */
									/* Can delete/ignore if not using ATD	 */
									/* ATD0 = 0x02C0, ATD1 = 0x0080          */
											
#define ECHO_ATD_CHANNEL	0		/* Channel on the MCU ATD to use    	 */
									/* 0-7 for ATD0                          */
									/* 0-15 for ATD1                         */
									/* Can delete/ignore if not using ATD	 */

#define ECHO_ATD_INPUT		0			/* Select analog input pin			 */
										/* 0-7 for ATD0					 	 */
										/* 0-15 for ATD0 					 */									

#define ECHO_ATD_DJM		0 		/* Set up of the DJM bit for the ATD	 */
									/* Can delete/ignore if not using ATD	 */

#define ECHO_ATD_RES8		1		/* Set up of the RES8 bit for the ATD	 */
									/* Can delete/ignore if not using ATD	 */

/******************************************************************************
* Miscellaneous
******************************************************************************/
#define ECHO_SWITCH_LEVEL   	0			/* Set active level of SWITCH pin*/
											/* 0 = Rx low, Tx high			 */
											/* 1 = Tx low, Rx high			 */

#define ECHO_LVD_ENABLE		    0			/* Enable low voltage detection	 */
											/* 0 = Disabled					 */
											/* 1 = Enabled					 */

#define ECHO_MCU_BUS_SPEED	    24000000	/* In Hz						 */


#define ECHO_RX_TIMEOUT_BITS	32	/* Number of bit-times to wait on	 	 */
									/* the next byte arriving before	 	 */
									/* assuming an error and timing out	 	 */
									/* back to the ready state (up to 255)	 */


/******************************************************************************
* These may be omitted depending on the hardware setup								
******************************************************************************/

//#define ECHO_LVD			PORTC_PC1	/* Define pin for LVD				 */
//#define ECHO_LVD_DDR	    DDRC_DDRC1  /* If not required,delete #defines	 */

//#define ECHO_STROBE		PORTC_PC2	/* Define pin used for Strobe		 */
//#define ECHO_STROBE_DDR	DDRC_DDRC2  /* If hardwired,delete #defines		 */

/******************************************************************************
* These are required for use with Motorola's rf modules
******************************************************************************/

//#define ECHO_ENABLEPA			PORTC_PC3	/* Define pin used for Power amp */
											/* enable						 */
//#define ECHO_ENABLEPA_DDR		DDRC_DDRC3  /* If hardwired, delete #defines */

//#define ECHO_ENABLELNA		PORTC_PC4	/* Define pin used for LNA		 */
//#define ECHO_ENABLELNA_DDR	DDRC_DDRC4	/* If hardwired,delete #defines	 */



/******************************************************************************
* This defines default values for  #defines in the Echo.h , or prints errors if
* missing or incorrect values have been chosen.	  DO NOT EDIT THIS SECTION!!
******************************************************************************/

#ifndef ECHO_CONFB
    #error "You must #define symbol ECHO_CONFB in Echo.H header file"
#endif

#ifndef ECHO_CONFB_DDR
    #error "You must #define symbol ECHO_CONFB_DDR in Echo.H header file"
#endif

#ifndef ECHO_SEB
    #error "You must #define symbol ECHO_SEB in Echo.H header file"
#endif

#ifndef ECHO_SEB_DDR
    #error "You must #define symbol ECHO_SEB_DDR in Echo.H header file"
#endif

/* RSSIC pin not used in BCD, thus commented */
/* #ifndef ECHO_RSSIC
    #error "You must #define symbol ECHO_RSSIC in Echo.H header file"
#endif

#ifndef ECHO_RSSIC_DDR
    #error "You must #define symbol ECHO_RSSIC_DDR in Echo.H header file"
#endif */


#ifndef ECHO_SPI_ADDRESS
    #error "You must #define symbol ECHO_SPI_ADDRESS in Echo.H header file"
#endif

#ifndef ECHO_SPI_CLOCK_SPEED
    #error "You must #define symbol ECHO_SPI_CLOCK_SPEED in Echo.H header file"
#endif


#ifndef ECHO_MAX_DATA_SIZE
    #error "You must #define symbol ECHO_MAX_DATA_SIZE in Echo.H header file"
#endif

#if ECHO_MAX_DATA_SIZE > 127
    #error "ECHO_MAX_DATA_SIZE in Echo.h must be in range 0- 127"
#endif

#ifndef ECHO_RX_BUF_COUNT
    #error "You must #define symbol ECHO_RX_BUF_COUNT in Echo.H header file"
#endif

#if ECHO_RX_BUF_COUNT < 1
    #error "ECHO_RX_BUF_COUNT in Echo.H must be 1 or more"
#endif


#ifndef ECHO_MODE_VALUE
    #error "You must #define symbol ECHO_MODE_VALUE in Echo.H header file"
#endif

#if ECHO_MODE_VALUE == ECHO_OOK
	#ifndef ECHO_MODE_OOKREF
	    #error "You must #define symbol ECHO_MODE_OOKREF when using OOK \
	    		modulation in Echo.H header file"
	#endif
	
	#if ECHO_MODE_OOKREF != 0 && ECHO_MODE_OOKREF != 1
	    #error "ECHO_MODE_OOKREF must be 1 or 0 in Echo.h header file"
	#endif
#else
	#if ECHO_MODE_VALUE == ECHO_FSK
		// It's ok so do nothing
	#else
		#error "You must set ECHO_MODE_VALUE to ECHO_OOK or ECHO_FSK in \
				Echo.H header file"
	#endif
#endif


#ifndef ECHO_BAND_VALUE
	#error "You must #define symbol ECHO_BAND_VALUE in Echo.H header file"
#endif

#if ECHO_BAND_VALUE == ECHO_F315MHz
	#define ECHO_LOF_CF_VALUE	0x80
#elif ECHO_BAND_VALUE == ECHO_F434MHz
	#define ECHO_LOF_CF_VALUE	0x50
#elif ECHO_BAND_VALUE == ECHO_F868MHz
	#define ECHO_LOF_CF_VALUE	0x70
#elif ECHO_BAND_VALUE == ECHO_F304MHz
	#define ECHO_LOF_CF_VALUE	0x00
#elif ECHO_BAND_VALUE == ECHO_F916MHz
	#define ECHO_LOF_CF_VALUE	0xF0
#else
	#error "You must set ECHO_BAND_VALUE to ECHO_F304MHz, ECHO_F315MHz, \
			ECHO_F434MHz, ECHO_F868MHz or ECHO_F916MHz in Echo.H header file"
#endif


#ifndef ECHO_DATA_RATE
    #error "You must #define symbol ECHO_DATA_RATE in Echo.h header file"
#endif

#if ECHO_DATA_RATE >= 2000 && ECHO_DATA_RATE <= 2800
	#define ECHO_DR_VALUE	0
#elif ECHO_DATA_RATE >= 4000 && ECHO_DATA_RATE <= 5600
	#define ECHO_DR_VALUE	1
#elif ECHO_DATA_RATE >= 8000 && ECHO_DATA_RATE <= 10600
	#define ECHO_DR_VALUE	2
#elif ECHO_DATA_RATE >= 16000 && ECHO_DATA_RATE <= 22400
	#define ECHO_DR_VALUE	3
#else
	#error "ECHO_DATA_RATE must be between 2000-2800, 4000-5600, 8000-10600 \
			or 16000-22400 kbaud in Echo.h header file"
#endif


#ifndef ECHO_ID_LENGTH
    #error "You must #define symbol ECHO_ID_LENGTH in Echo.H header file"
#endif

#ifndef ECHO_ID_VALUE
    #error "You must #define symbol ECHO_ID_VALUE in Echo.H header file"
#endif

#if   ECHO_ID_LENGTH == 2
							#define ECHO_IDL 0
#elif ECHO_ID_LENGTH == 4
							#define ECHO_IDL 1
#elif ECHO_ID_LENGTH == 5
							#define ECHO_IDL 2
#elif ECHO_ID_LENGTH == 6
							#define ECHO_IDL 3
#elif ECHO_ID_LENGTH == 8					    /* ID length = 8 used for	 */
							#define ECHO_IDL 3	/* compatibility with		 */
#else											/* Romeo/Tango 				 */
	#error "ECHO_ID_LENGTH must be 2, 4, 5, 6 or 8 bits long"
#endif
												

#ifndef ECHO_HEADER_LENGTH
    #error "You must #define symbol ECHO_HEADER_LENGTH in Echo.H header file"
#endif

#ifndef ECHO_HEADER_VALUE
    #error "You must #define symbol ECHO_HEADER_VALUE in Echo.H header file"
#endif


#if   ECHO_HEADER_LENGTH == 1
								#define ECHO_HDL 0
#elif ECHO_HEADER_LENGTH == 2
								#define ECHO_HDL 1
#elif ECHO_HEADER_LENGTH == 4
								#define ECHO_HDL 2
#elif ECHO_HEADER_LENGTH == 6
								#define ECHO_HDL 3
#else
	#error "ECHO_HEADER_LENGTH must be 1, 2, 4 or 6 bits long"
#endif


#ifndef ECHO_SOE_VALUE
    #error "You must #define symbol ECHO_SOE_VALUE in Echo.H header file"
#endif

#if ECHO_SOE_VALUE != 0 && ECHO_SOE_VALUE != 1
    #error "ECHO_SOE_VALUE must be 1 or 0 in Echo.h header file"
#endif


#ifndef ECHO_RXON_VALUE
    #error "You must #define symbol ECHO_RXON_VALUE in Echo.H header file"
#endif

#ifndef ECHO_RXOFF_VALUE
    #error "You must #define symbol ECHO_RXOFF_VALUE in Echo.H header file"
#endif


#if ECHO_RXON_VALUE < 1 || ECHO_RXON_VALUE > 15
    #error "ECHO_RXON_VALUE must be between 1 and 15 inclusive in Echo.h \
    		header file"
#endif

#if ECHO_RXOFF_VALUE < 0 || ECHO_RXOFF_VALUE > 7
    #error "ECHO_RXOFF_VALUE must be between 0 and 7 inclusive in Echo.h \
    		header file"
#endif
			

#ifndef ECHO_TIMER_ADDRESS
    #error "You must #define symbol ECHO_TIMER_ADDRESS in Echo.H header file"
#endif

#ifndef ECHO_TIMER_CHANNEL
    #error "You must #define symbol ECHO_TIMER_CHANNEL in Echo.H header file"
#endif

#if ECHO_TIMER_CHANNEL == 7
	#error "ECHO_TIMER_CHANNEL must be between 0 and 6 inclusive in Echo.h \
			header file (channel 7 reserved for main counter reset)"
#endif

/* #ifndef ECHO_TIMER_CLOCK_SOURCE
	#error "You must #define symbol ECHO_TIMER_CLOCK_SOURCE in Echo.h header \
    		file"
#endif */

#ifndef ECHO_USE_DATACLK
    #error "You must #define symbol ECHO_USE_DATACLK in Echo.h header file"
#endif

#if ECHO_USE_DATACLK != 0 && ECHO_USE_DATACLK != 1
    #error "ECHO_USE_DATACLK must be 1 or 0 in Echo.h header file"
#endif

#ifndef ECHO_TIMER_CLOCK_SPEED
    #error "You must #define symbol ECHO_TIMER_CLOCK_SPEED in Echo.h header \
    		file"
#endif


#ifndef ECHO_TIMER_PRESCALE
    #error "You must #define symbol ECHO_TIMER_PRESCALE in Echo.h header file"
#endif



#ifndef ECHO_CRYSTAL_FREQUENCY
    #error "You must #define symbol ECHO_CRYSTAL_FREQUENCY in Echo.h header \
    		file"
#endif



#ifndef ECHO_USE_MCU_ATD
    #error "You must #define symbol ECHO_USE_MCU_ATD in Echo.h header file"
#endif

#if ECHO_USE_MCU_ATD == 1
	#ifndef ECHO_ATD_ADDRESS
	    #error "You must #define symbol ECHO_ATD_ADDRESS when using the MCU \
	    		ATD in Echo.h header file"
	#endif
	
	#ifndef ECHO_ATD_CHANNEL
	    #error "You must #define symbol ECHO_ATD_CHANNEL when using the MCU \
	    		ATD in Echo.h header file"
	#endif
	
	#ifndef ECHO_ATD_INPUT
	    #error "You must #define symbol ECHO_ATD_INPUT when using the MCU \
	    		ATD in Echo.h header file"
	#endif
	
	#ifndef ECHO_ATD
	    #error "You must #define symbol ECHO_ATD when using the MCU ATD in \
	    		Echo.h header file"
	#endif
	
	#if ECHO_ATD == 0
	    #if ECHO_ATD_CHANNEL < 0 || ECHO_ATD_CHANNEL > 7
	        #error "ECHO_ATD_CHANNEL must be between 0 and 7 inclusive in \
	        		Echo.h header file"
	    #endif
    #elif ECHO_ATD == 1 
        #if ECHO_ATD_CHANNEL < 0 || ECHO_ATD_CHANNEL > 15
	        #error "ECHO_ATD_CHANNEL must be between 0 and 15 inclusive in \
	        		Echo.h header file"
	    #endif
	#endif
	
	#if ECHO_ATD == 0
	    #if ECHO_ATD_INPUT < 0 || ECHO_ATD_CHANNEL > 7
	        #error "ECHO_ATD_INPUT must be between 0 and 7 inclusive in \
	        		Echo.h header file"
	    #endif
    #elif ECHO_ATD == 1 
        #if ECHO_ATD_INPUT < 0 || ECHO_ATD_CHANNEL > 15
	        #error "ECHO_ATD_INPUT must be between 0 and 15 inclusive in \
	        		Echo.h header file"
	    #endif
	#endif
#endif



#ifndef ECHO_SWITCH_LEVEL
    #error "You must #define symbol ECHO_SWITCH_LEVEL in Echo.h header file"
#endif

#if ECHO_SWITCH_LEVEL != 0 && ECHO_SWITCH_LEVEL != 1
    #error "ECHO_SWITCH_LEVEL must be 1 or 0 in Echo.h header file"
#endif


#ifndef ECHO_LVD_ENABLE
    #error "You must #define symbol ECHO_LVD_ENABLE in Echo.h header file"
#endif

#if ECHO_LVD_ENABLE != 0 && ECHO_LVD_ENABLE != 1
    #error "ECHO_LVD_ENABLE must be 1 or 0 in Echo.h header file"
#endif



/******************************************************************************
* This section defines various values used in the driver    
*				DO NOT EDIT THIS SECTION!!								
******************************************************************************/

/******************************************************************************
* ATD configuration
******************************************************************************/

/* Register address offsets for MC9S12XDP512 ATD0/ATD1					     */

#define ECHO_ATDCTL2  *(volatile unsigned char *)(ECHO_ATD_ADDRESS+2)
															/* ATD Control 2 */
#define ECHO_ATDCTL4  *(volatile unsigned char *)(ECHO_ATD_ADDRESS+4)		
															/* ATD Control 4 */
#define ECHO_ATDCTL5  *(volatile unsigned char *)(ECHO_ATD_ADDRESS+5)
															/* ATD Control 5 */

#if ECHO_ATD_CHANNEL > 7
    #define ECHO_ATDSTAT *(volatile unsigned char *)(ECHO_ATD_ADDRESS+10)
    														/* ATD Status 2  */
													 		/* ATD1 only     */
	#define ECHO_ATDDIEN *(volatile unsigned char *)(ECHO_ATD_ADDRESS+12)
													/* ATD Input Enable 0 	 */
													/* ATD1 only     	 	 */
#else ECHO_ATD_CHANNEL
    #define ECHO_ATDSTAT *(volatile unsigned char *)(ECHO_ATD_ADDRESS+11)
    														/* ATD Status 1	 */
	#define ECHO_ATDDIEN *(volatile unsigned char *)(ECHO_ATD_ADDRESS+13)
#endif 												/* ATD Input Enable  	 */


#define ECHO_ATDDRxH *(volatile unsigned char *)\
		(ECHO_ATD_ADDRESS+16+(2*ECHO_ATD_CHANNEL)+0)    /* ATD Result (High) */
														
#define ECHO_ATDDRxL *(volatile unsigned char *)\
		(ECHO_ATD_ADDRESS+16+(2*ECHO_ATD_CHANNEL)+1)    /* ATD Result (Low)  */														 
                                                                                  
/* ATD bit masks													    	 */
#define ECHO_ATDCTL2_ADPU	0x80							/* ATD Power Up  */

#if ECHO_ATD_CHANNEL > 7                                   /* ATD conversion */
    #define ECHO_ATDSTAT_CCF (1 << (ECHO_ATD_CHANNEL-8))   /* complete flag  */
#else                                                             
    #define ECHO_ATDSTAT_CCF (1 << ECHO_ATD_CHANNEL)
#endif



/******************************************************************************
* SPI configuration                                   
******************************************************************************/

/* Register address offsets for MC9S12XDP512 SPI							 */
#define ECHO_SPIxC1 *(volatile unsigned char *)(ECHO_SPI_ADDRESS+0) 	
														/* SPI Ctrl reg #1	 */
#define ECHO_SPIxC2 *(volatile unsigned char *)(ECHO_SPI_ADDRESS+1)
													 	/* SPI Ctrl reg #2	 */
#define ECHO_SPIxBR *(volatile unsigned char *)(ECHO_SPI_ADDRESS+2)
														/* SPI Baud rate reg */
#define ECHO_SPIxSR	*(volatile unsigned char *)(ECHO_SPI_ADDRESS+3)
														/* SPI Status reg	 */
#define ECHO_SPIxDR *(volatile unsigned char *)(ECHO_SPI_ADDRESS+5)
														/* SPI Data reg		 */

/* SPI bit masks															 */
#define ECHO_SPIxC1_SPIE	0x80		/* SPI Rx Interrupt enable bit mask	 */
#define ECHO_SPIxC1_SPE		0x40		/* SPI system enable bit mask		 */
#define ECHO_SPIxC1_MSTR	0x10		/* SPI master/slave mode bit mask	 */

#define ECHO_SPIxSR_SPIF	0x80		/* SPI read buffer full bit mask	 */
#define ECHO_SPIxSR_SPTEF	0x20		/* SPI Tx buffer empty bit mask		 */

/* SPI baud rate divider													 */
/* Chooses appropriate baud rate divisor to provide max comms speed to Echo	 */
#define ECHO_MAX_SPI_SPEED		615000				/* Tsclk = 1us (minimum) */

#define ECHO_SPI_BAUD_RATE_PRESCALER	2	/* 0 => divide by 1				 */
											/* Can set this up if necessary  */

#if (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	*ECHO_MAX_SPI_SPEED)) <= 2
    #define ECHO_SPI_BAUD_RATE_DIVISOR  0

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	  *ECHO_MAX_SPI_SPEED)) <= 4
    #define ECHO_SPI_BAUD_RATE_DIVISOR  1

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	  *ECHO_MAX_SPI_SPEED)) <= 8
    #define ECHO_SPI_BAUD_RATE_DIVISOR  2

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	  *ECHO_MAX_SPI_SPEED)) <= 16
    #define ECHO_SPI_BAUD_RATE_DIVISOR  3

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	  *ECHO_MAX_SPI_SPEED)) <= 32
    #define ECHO_SPI_BAUD_RATE_DIVISOR  4

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	  *ECHO_MAX_SPI_SPEED)) <= 64
    #define ECHO_SPI_BAUD_RATE_DIVISOR  5

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	  *ECHO_MAX_SPI_SPEED)) <= 128
    #define ECHO_SPI_BAUD_RATE_DIVISOR  6

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)\
	  *ECHO_MAX_SPI_SPEED)) <= 256
    #define ECHO_SPI_BAUD_RATE_DIVISOR  7

#else
	#error "MCU SPI Baud Rate too high: increase ECHO_SPI_BAUD_RATE_PRESCALER \
			in header file Echo.h"
#endif


/* Enable/disable Data Manager	!!DATA MANAGER ALWAYS USED IN THIS VERSION!! */
#define ECHO_DME_VALUE     1		        /* 0 = Data manager disabled     */
											/* 1 = Data manager enabled		 */


/******************************************************************************
* Timer configuration
******************************************************************************/

/* Register address offsets for MC9S12XDP512 timer */
#define ECHO_TIOS	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+0) 
													/* Timer IC/OC select 	 */
#define ECHO_TSCR1	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+6)
													/* Tmr system control 1	 */
#if ECHO_TIMER_CHANNEL > 3 
	#define ECHO_TCTL *(volatile unsigned char *)(ECHO_TIMER_ADDRESS+8) 
													/* Timer control 1		 */
#elif ECHO_TIMER_CHANNEL < 4 										  
	#define ECHO_TCTL *(volatile unsigned char *)(ECHO_TIMER_ADDRESS+9)
													/* Timer control 2		 */
#endif

#define ECHO_TIE	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+12)
													/* Timer int enable	 	 */
#define ECHO_TSCR2	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+13)	 	
													/* Tmr system control 2	 */
#define ECHO_TFLG1	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+14)
													/* Timer int flags 1	 */
#define ECHO_MCCTL	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+38)
													/* Modulus control		 */
#define ECHO_MCFLG	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+39)
													/* Modulus flag			 */
#define ECHO_MCCNTH	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+54)
													/* Modulus count H		 */
#define ECHO_MCCNTL	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+55)
													/* Modulus count L		 */

/* Registers for each timer channel */
#define ECHO_TCxH	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+16\
					 +(2*ECHO_TIMER_CHANNEL)+0)								 
													/* Tmr IC/OC Register H  */
#define ECHO_TCxL	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+16\
					 +(2*ECHO_TIMER_CHANNEL)+1)							  	 
													/* Tmr IC/OC Register L  */

#define ECHO_TC7H	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+16\
					 +(2*7)+0)
					 						/* Channel 7 IC/OC Register H	 */
#define ECHO_TC7L	*(volatile unsigned char *)(ECHO_TIMER_ADDRESS+16\
					 +(2*7)+1)
					 						/* Channel 7 IC/OC Register L	 */
					 						

/* Timer control reg masks */
#define ECHO_TIMER_ON	0x80				/* OR this value to tmr control  */
											/* reg 1 to enable clock		 */
#define ECHO_TIMER_OFF	0x7F				/* AND this value to tmr control */
											/* reg 1 to disable clock		 */

#define ECHO_IC_OC	((1 << ECHO_TIMER_CHANNEL) | 0x80)	/* IC/OC select mask */
										/* for selected channel + channel 7  */

#define ECHO_TIMER_INT	(1 << ECHO_TIMER_CHANNEL)		/* Interrupt mask	 */
														/* TIE, TFLG1 regs.	 */

#define ECHO_MODMC		0x40			/* Modulus Down-Counter enable mask	 */
#define ECHO_MCEN		0x04			/* Modulus mode enable mask			 */
#define ECHO_MCZI		0x80			/* Modulus interrupt enable mask	 */
#define ECHO_TCRE		0x08			/* Timer counter reset enable		 */

#if ECHO_TIMER_CHANNEL > 3										
	#define ECHO_TIMER_PIN_OFF		(0x03 << (2*(ECHO_TIMER_CHANNEL-4)))    
													/* Turn off channel pin	 */
	#define ECHO_CLEAR_ON_COMPARE	(0x02 << (2*(ECHO_TIMER_CHANNEL-4)))
    												/* Output a 0 NRZ 		 */
	#define ECHO_SET_ON_COMPARE		(0x03 << (2*(ECHO_TIMER_CHANNEL-4)))
    												/* Output a 1 NRZ 		 */
#elif ECHO_TIMER_CHANNEL < 4
	#define ECHO_TIMER_PIN_OFF		(0x03 << (2*ECHO_TIMER_CHANNEL))
													/* Turn off channel pin	 */
	#define ECHO_CLEAR_ON_COMPARE	(0x02 << (2*ECHO_TIMER_CHANNEL))
													/* Output a 0 NRZ 		 */
	#define ECHO_SET_ON_COMPARE		(0x03 << (2*ECHO_TIMER_CHANNEL))
													/* Output a 1 NRZ 		 */
#endif

/* #define ECHO_PWM_ZERO	0x64 */	/* PWM Low-True  => _| (0 Manchester)	 */
/* #define ECHO_PWM_ONE		0x68 */	/* PWM High-True => |_ (1 Manchester)	 */

/* Miscellaneous timer calculations			   								 */
/* #if ECHO_TIMER_CLOCK_SOURCE == 3	*/
/*	#define ECHO_TIMER_CLK_IN_CHANNEL	0*/ 
										/* Timer channel used for clk in	 */
										/* (usually timer ch 0 on HCS08) 	 */
										/* Delete if not using clk input 	 */
// #endif


/******************************************************************************
* This part may need changed to include 304MHz and 916MHz bands...						
******************************************************************************/
#if ECHO_BAND_VALUE == ECHO_F315MHz
	#define ECHO_DIGCLK_DIVISOR		30
	#define ECHO_DATACLK_DIVISOR	60
#else
	#define ECHO_DIGCLK_DIVISOR		40          		/* 434/868MHz band 	 */
	#define ECHO_DATACLK_DIVISOR	80
#endif
/*****************************************************************************/


/* #ifdef ECHO_TIMER_CLK_IN_CHANNEL */	/* If using an external clock source */
/*	#if ECHO_USE_DATACLK == 1
		#undef ECHO_TIMER_CLOCK_SPEED
		#define ECHO_TIMER_CLOCK_SPEED	(ECHO_CRYSTAL_FREQUENCY\
										 /ECHO_DATACLK_DIVISOR)
	#endif
#endif																		 */

/* Calculate the modulus and values											 */
#define ECHO_TIMER_MODULUS  ((ECHO_TIMER_CLOCK_SPEED/ECHO_DATA_RATE)\
							 /ECHO_TIMER_PRESCALE)

#define ECHO_HALF_TIMER_MODULUS		(ECHO_TIMER_MODULUS/2)

#define ECHO_MODH	(ECHO_TIMER_MODULUS/256)
#define ECHO_MODL	(ECHO_TIMER_MODULUS)

#define ECHO_COMH	(ECHO_HALF_TIMER_MODULUS/256)
#define ECHO_COML	(ECHO_HALF_TIMER_MODULUS)

/* Number of bit times for greater than 2ms power on delay (2ms => 500Hz) 	 */
#define ECHO_2MS_DELAY  (((ECHO_TIMER_CLOCK_SPEED/500)/ECHO_TIMER_MODULUS)+1)

/* Number of bit times for 1.2ms Echo config power on delay (1.2ms => 833Hz) */
#define ECHO_1200uS_DELAY  ((ECHO_DATA_RATE/833)+1)

/* Number of bit times for 500 microsecond Tx->Rx mode switch delay 		 */
/* (500uS => 2000Hz)														 */
#define ECHO_500uS_DELAY	((ECHO_DATA_RATE/2000)+1)

/* Number of bit-times for a 200 us preamble period							 */
/* (+1 to make sure >200 us)												 */
/* Also need additional half-bit added because of the way PREAMBLE_1 state	 */ 
/* is implemented:  ast count is cut short to 1/2 bit-time by PWM low true 	 */
/* pulse. Hence, 1 + 1/2 = 3/2 = 7500/5000									 */
#define ECHO_PREAMBLE_200uS		((ECHO_DATA_RATE+7500)/5000)

/* Number of ticks for RSSIC to stay high (around 53 us)					 */
//#define ECHO_RSSIC_TICKS	((32*((ECHO_DIGCLK_DIVISOR*ECHO_TIMER_CLOCK_SPEED)\
//							  /ECHO_CRYSTAL_FREQUENCY)/ECHO_TIMER_PRESCALE)+1)
#define ECHO_RSSIC_TICKS	(((55*ECHO_TIMER_CLOCK_SPEED)/(1000000\
							   *ECHO_TIMER_PRESCALE))+1)

/* Number of ticks for an ADC conversion (max. 60 us)				 */
#define ECHO_ATD_TICKS		(((60*ECHO_TIMER_CLOCK_SPEED)/(1000000\
							   *ECHO_TIMER_PRESCALE))+1)


/******************************************************************************
* Echo registers
******************************************************************************/ 

#define ECHO_CONFIG1_REG	0
#define ECHO_CONFIG2_REG	1
#define ECHO_CONFIG3_REG	2
#define ECHO_COMMAND_REG	3
#define ECHO_F1_REG			4
#define ECHO_F0_REG			5
#define ECHO_FT2_REG		6
#define ECHO_FT1_REG		7
#define ECHO_FT0_REG		8
#define ECHO_RXONOFF_REG	9
#define ECHO_ID_REG			10
#define ECHO_HEADER_REG		11
#define ECHO_RSSI_REG		12

/*Register: CONFIG2*/
#define ECHO_BIT_FRM		0x40
#define ECHO_BIT_TRXE		0x04

/*Register: COMMAND*/
#define ECHO_BIT_FAGC		0x02
#define ECHO_BIT_RAGC		0x04
#define ECHO_BIT_RSSIE		0x10
#define ECHO_BIT_MODE		0x20
#define ECHO_BIT_IFLA		0x40

/*  CONFIG1 byte															 */
/* This macro constructs the CONFIG1 byte									 */
#define ECHO_CONFIG1_REG_VALUE	(ECHO_LOF_CF_VALUE | ECHO_SWITCH_LEVEL << 2\
								| ECHO_LVD_ENABLE << 1 | ECHO_USE_DATACLK)

/* CONFIG2 byte																 */
/* This macro constructs the CONFIG2 byte									 */
#define ECHO_CONFIG2_REG_VALUE	(ECHO_MODE_OOKREF << 7 | ECHO_MODE_VALUE << 5\
				| ECHO_DR_VALUE << 3 | ECHO_DME_VALUE << 1 | ECHO_SOE_VALUE)

/* CONFIG3 byte - no setup necessary, power/sensitivity controls can be		 */
/*				  setup post init											 */
#define ECHO_CONFIG3_REG_VALUE	0x00

/* COMMAND byte - setup to Echo default values								 */
#define ECHO_COMMAND_REG_VALUE	0x09

/* F and FT registers - default values										 */
#define ECHO_F1_REG_VALUE		0x48
#define ECHO_F0_REG_VALUE		0x00

#define ECHO_FT2_REG_VALUE		0x70
#define ECHO_FT1_REG_VALUE		0x07
#define ECHO_FT0_REG_VALUE		0x01

/* RXONOFF byte - constructed from RXON and RXOFF							 */
#define ECHO_RXONOFF_REG_VALUE	(ECHO_RXON_VALUE << 3 | ECHO_RXOFF_VALUE)

/* ID byte - constructed from ID length and the ID itself					 */
#if ECHO_ID_LENGTH == 8
	#define ECHO_ID_REG_VALUE	(ECHO_IDL << 6 | ((ECHO_ID_VALUE>>2) & 0x3F))
#else
	#define ECHO_ID_REG_VALUE	(ECHO_IDL << 6 | (ECHO_ID_VALUE & 0x3F))
#endif

/* HEADER byte - constructed from Header length and the header itself		 */
#define ECHO_HEADER_REG_VALUE	(ECHO_HDL << 6 | (ECHO_HEADER_VALUE & 0x3F))
																			
/* RSSI byte - read only													 */
#define ECHO_RSSI_REG_VALUE		0x00
 

/******************************************************************************
* Status, States and Functions
******************************************************************************/

#define ECHO_BUFFER_FULL	0x80		/* Mask for Rx buffer full flag		 */
#define ECHO_CHECKSUM_ERROR	0x80		/* Mask for Rx checksum error		 */
#define ECHO_RSSI_BIT		0x20		/* Mask for RSSI present flag		 */

typedef union
{
	unsigned char Byte;
	struct
	{
		unsigned char IDHeaderSelect	:1;			/* 0 = Send ID,		 	 */
													/* 1 = Send Header	 	 */
		unsigned char CompleteSend		:1;			/* 0 = Single seq	 	 */
													/* 1 = Complete telegram */
		unsigned char IDRepeat			:1; 		/* 0 = Single ID		 */
													/* 1 = Repeat ID		 */
		unsigned char reserved			:5;
	}Bits;
}tECHO_TXCONFIG;

typedef union
{
	unsigned int Word;
	struct {
		unsigned char ByteH;
		unsigned char ByteL;
	}Bytes;
	struct
	{
		unsigned int EnableDelay	:1;	/* 1 = Echo powering up				 */
		unsigned int ModeSwitchDelay:1;	/* 1 = Echo switching modes			 */
		unsigned int RSSI_Enabled	:1;	/* 1 = RSSI enabled, 0 = RSSI dis.	 */
		unsigned int RSSI_InProgress:1;	/* 1 = RSSI being read				 */
		unsigned int Error			:1;	/* 1 = Error occured eg config while 
										 	   in Tx						 */
		unsigned int LVD			:1;	/* 1 = Low Voltage Detected			 */
		unsigned int Timeout		:1;	/* 1 = Timeout from an Rx state 	 
										       occured						 */
		unsigned int reserved		:1;	/* Reserved							 */

		unsigned int Enabled		:1;	/* 1 = Echo enabled, 0 = Echo dis.	 */
		unsigned int Busy			:1;	/* 1 = Echo busy, 0 = Echo idle		 */
		unsigned int MsgReady		:1;	/* 1 = Message waiting, 0 = no msg   */
		unsigned int Tx				:1;	/* 1 = Transmitting					 */
		unsigned int Rx				:1;	/* 1 = Receiving					 */
		unsigned int Checksum		:1; /* 1 = Current msg has a checksum 
											   error						 */
		unsigned int Overrun		:1; /* 1 = Msg buffer overrun, last msg 
											   lost							 */
		unsigned int Mode			:1;	/* 1 = Tx Mode, 0 = Rx Mode			 */
	}Bits;
}tECHO_STATUS;

/* Masks for status bits													 */
#define ECHO_STATUS_ENABLED				0x0001
#define ECHO_STATUS_BUSY				0x0002
#define ECHO_STATUS_MSGREADY			0x0004
#define ECHO_STATUS_TX					0x0008
#define ECHO_STATUS_RX					0x0010
#define ECHO_STATUS_CHECKSUM			0x0020
#define ECHO_STATUS_OVERRUN				0x0040
#define ECHO_STATUS_MODE				0x0080
#define ECHO_STATUS_ENABLEDELAY			0x0100
#define ECHO_STATUS_MODESWITCHDELAY		0x0200
#define ECHO_STATUS_RSSI_ENABLED		0x0400
#define ECHO_STATUS_RSSI_INPROGRESS		0x0800
#define ECHO_STATUS_ERROR				0x1000
#define ECHO_STATUS_LVD					0x2000
#define ECHO_STATUS_TIMEOUT				0x4000

/* Driver delay states														 */
#define ECHO_ENABLE_DELAY		0
#define ECHO_TXRX_SWITCH_DELAY	2

/* Tx state machine states													 */
#define ECHO_STARTUP		3
#define ECHO_RXTX_SWITCH	1
#define ECHO_PREAMBLE_1		4
#define ECHO_PREAMBLE_2		5
#define ECHO_SENDID			6
#define ECHO_SENDHEADER		25
#define ECHO_SENDDATA		7
#define ECHO_SENDCHECKSUM	20
#define ECHO_EXTRA_BIT		8
#define ECHO_EOM_1			9
#define ECHO_EOM_2			10
#define ECHO_SWITCHBACK		17
#define ECHO_END_NOSWITCH	19
#define ECHO_END			11
#define ECHO_WAIT			18 

/* Rx state machine states													 */
#define ECHO_READY			12
#define ECHO_READ_DATA		13
#define ECHO_LAST_BYTE		14
#define ECHO_READ_RSSI_1	15
#define ECHO_READ_RSSI_2	16


#define ECHO_CONFIG_DELAY	21
#define ECHO_DO_CONFIG		22

#define ECHO_READ_DIGITAL_RSSI	23
#define ECHO_READ_ANALOGUE_RSSI	24

/* Function prototypes														 */
void Echo_Initialize(void);

void Echo_Enable(void);
void Echo_Disable(void);

tECHO_STATUS Echo_DriverStatus(void);

void Echo_ClearError(void);

void Echo_SendPreambleID(void);
void Echo_SendData(void);
void Echo_SendMessage(void);
void Echo_SendIDRepeat(unsigned char repeatCount);

void Echo_StrobeHigh(void);
void Echo_StrobeLow(void);
void Echo_StrobeTriState(void);

interrupt void Echo_TxTimer_Interrupt(void);
interrupt void Echo_RxSPI_Interrupt(void);

#if ECHO_MODE_VALUE == ECHO_OOK
	void Echo_SetFreq(unsigned int carrier);
	void Echo_SetFreqNoFRM(unsigned int localOscillator, \
						   unsigned int carrier0);
#else
	void Echo_SetFreq(unsigned int carrier, unsigned char deltaF);
	void Echo_SetFreqNoFRM(unsigned int localOscillator,
						   unsigned int carrier0,
						   unsigned int carrier1);
#endif

#ifdef ECHO_RSSIC
	void Echo_EnableRSSI(void);
	void Echo_DisableRSSI(void);
	void Echo_ReadDigitalRSSI(void);
	void Echo_ReadAnalogueRSSI(void);
#endif

void Echo_SetRxSensitivity(unsigned char level);
void Echo_SetTxPower(unsigned char level);

void Echo_RagcHigh(void);
void Echo_RagcLow(void);
void Echo_FagcHigh(void);
void Echo_FagcLow(void);

void Echo_ChangeConfig(unsigned char numReg,
					   unsigned char startReg,
					   unsigned char *regData,
					   unsigned char readWrite
					   );

#endif