/******************************************************************************
*
*	   Copyright (C) 2004 Motorola, Inc.
*	   All Rights Reserved
*
* Filename:		$RCSfile: Echo.h,v $
* Author:		$Author: r22624 $
* Locker:		$Locker:  $
* State:		$State: Exp $
* Revision:		$Revision: 1.0 $
*
* Functions:	Echo software driver header file for HCS08
*
* Description:	This is header file for Echo software driver for HCS08.
*				Based on Tango/Romeo and their driver header files.
*
* Notes:
*
******************************************************************************/

#ifndef ECHO_H
#define ECHO_H


/****************************************************************************************/
/* This section defines some symbols for use below. DO NOT EDIT!!!!!						*/
#define ECHO_FSK	1
#define ECHO_OOK	0

#define ECHO_F304MHz	0
#define ECHO_F315MHz	1
#define ECHO_F434MHz	2
#define ECHO_F868MHz	3
#define ECHO_F916MHz	4

#define ECHO_BANK_A   0x40
#define ECHO_BANK_B   0
#define ECHO_BANK_BOTH 2
/****************************************************************************************/



/****************************************************************************************/
/*			THIS SECTION CONTAINS VALUES YOU MUST DEFINE!								*/
/*																						*/
#include "derivative.h"							/* Include peripheral declarations		*/

/************************************************/
/*                                              */
/* Common properties for both BANKs in MC33696  */
/*                                              */                                              
/************************************************/


#ifdef __HCS08__
/* --- Define required pins FOR HCS08!!! ---------------												*/
#define ECHO_CONFB				PTBD_PTBD5	  	/* Define pin used for CONFB			*/
#define ECHO_CONFB_DDR		PTBDD_PTBDD5

#define ECHO_SEB				  PTBD_PTBD4	  	/* Define pin used for SEB				*/
#define ECHO_SEB_DDR			PTBDD_PTBDD4  

#else
      
/* --- Define required pins FOR HC08!!! ---------------												*/
#define ECHO_CONFB				PTD_PTD1	  	/* Define pin used for CONFB			*/
#define ECHO_CONFB_DDR		DDRD_DDRD1

#define ECHO_SEB				  PTD_PTD0	  	/* Define pin used for SEB				*/
#define ECHO_SEB_DDR			DDRD_DDRD0

#endif 

/* --- Setup SPI --------------------------												*/
#define ECHO_SPI_ADDRESS		0x50			/* Location of SPI registers			*/
												/* Address varies from MCU to MCU		*/
#define ECHO_SPI_CLOCK_SPEED	32000000			/* SPI clock speed						*/

/* --- Timer set up -----------------------												*/
#define ECHO_TIMER_ADDRESS		0x60			/* Location of 1st timer register		*/
#define ECHO_TIMER_CHANNEL		0				/* Define which timer channel to use	*/
												/* Note:timer channels start from 0		*/

#define ECHO_TIMER_CLOCK_SOURCE	1				/* Use to set clock source for timer	*/
												/* 1 = Bus clock						*/
												/* 2 = XCLK- note,not all MCUs have XCLK*/							
												/* 3 = Ext clock						*/
												

#define ECHO_USE_DATACLK  0				/* Indicate if the Ext clock is DATACLK	*/
												/* output from Echo. If using DATACLK	*/
												/* and ECHO_TIMER_CLOCK_SOURCE = 3,		*/
												/* ECHO_TIMER_CLOCK_SPEED is replaced	*/
												/* with Fdataclk calculated instead.	*/
												/* 0 = dataclock not enabled			*/
												/* 1 = dataclock enabled				*/

#define ECHO_TIMER_CLOCK_SPEED	8000000			/* Set timer clock speed in Hz			*/

#define ECHO_TIMER_PRESCALE		1				/* Specify timer prescaler value		*/

#define ECHO_TIMER_DISABLE		1				/* Allows driver to turn off timer after*/
												/* use. Delete this #define if you want */
												/* timer to stay on						*/

#define ECHO_CRYSTAL_FREQUENCY	24190660		/* Crystal frequency (in Hz)			*/
												/* Typical values used					*/
												/* RF Output							*/ 
												/* 315MHz  - 17581400					*/
												/* 434MHz  - 24190660					*/
												/* 868MHz  - 24161390					*/



/* --- Buffering parameters ---------------												*/
#define ECHO_MAX_DATA_SIZE		18				/* Max length of data field in msg		*/

#define ECHO_RX_BUF_COUNT		4				/* Number of Rx buffers to allocate		*/
												/* An additional buffer is allocated	*/
												/* for internal use by the driver		*/
												/* Note: each buffer consumes			*/
												/* ECHO_MAX_DATA_SIZE+2 bytes in memory!*/


/* --- On/off control ---------------------												*/
#define ECHO_SOE_VALUE			0				/* 0 = strobe oscillator disabled		*/
												/* 1 = strobe oscillator enabled		*/
												

#define ECHO_RX_TIMEOUT_BITS	32				/* Number of bit-times to wait on		*/
												/* the next byte arriving before		*/
												/* assuming an error and timing out		*/
												/* back to the ready state (up to 255)	*/	

/* --- Low Voltage status -------------------                 */
#define ECHO_LVD_ENABLE			0				/* Enable low voltage detection			*/
												/* 0 = Disabled							*/
												/* 1 = Enabled							*/

/* --- Misc -------------------------------												*/
#define ECHO_MCU_BUS_SPEED		4000000			/* In Hz								*/

#define ECHO_SWITCH_LEVEL		1				/* Set active level of SWITCH o/p pin	*/
												/* 0 = Rx low, Tx high					*/
												/* 1 = Tx low, Rx high					*/
#define ECHO_AUTO_SWITCH  1 /* if is used both bank, then can switch automaticly 
                            to both banks used after each transmit */
                        /* 0 = Switching to both banks manually */
                        /* 1 = Switching to both banks automaticly */     												
																																				
												

/************************************************/
/*                                              */
/*       Properties for  BANK A in MC33696      */
/*                                              */                                              
/************************************************/

/* --- Echo Bank A Enable ------------           */
#define ECHO_BANK_A_EN     1 /* Switch if you want use  Bank A in MC33696 */
                          /* 0 - Bank B disable             */
                          /* 1 - Bank B enable              */
                            
#if ECHO_BANK_A_EN == 1
  /* --- Echo modulation parameters ---------												*/
  #define ECHO_MODE_VALUE			ECHO_OOK		/* ECHO_OOK = OOK reception				*/
  												/* ECHO_FSK = FSK reception				*/
  #define ECHO_MODE_DSREF		1				/* Select the data slicer reference in	*/
  												/* OOK mode: 0 = fixed, 1 = adaptive	*/
  												/* Can delete/ignore if using FSK		*/
  												
  #define ECHO_BAND_VALUE			ECHO_F434MHz	/* ECHO_F304MHz, ECHO_F315MHz,			*/
  												/* ECHO_F434MHz, ECHO_F868MHz,			*/
  												/* or ECHO_F916MHz						*/

  #define ECHO_DATA_RATE	  	2400			/* Set Echo data rate in Hz (before		*/
  												/* Manchester encoding)					*/


  /* --- ID and Header set up ---------------												*/
  #define ECHO_ID_LENGTH			6				/* 6 Length of ID (2,4,5,6 or 8 bits)		*/
  #define ECHO_ID_VALUE			0xC8			/* 11 ID word recognised by Echo			*/

  #define ECHO_HEADER_LENGTH		4				/* Length of header (1,2,4,6 bits)		*/
  #define ECHO_HEADER_VALUE		0x06			/* Header word recognised by Echo (must	*/
  												/* not be present in Preamble/ID)		*/



  /* These values are calculated from the Echo datasheet or supporting driver spreadsheet */
  #define ECHO_RXON_VALUE			15				/* On time:  1->15						*/
  #define ECHO_RXOFF_VALUE		1				/* Off time: 0->7						*/

  /* --- Misc -------------------------------												*/
  #define ECHO_AFFC_VALUE  0  /* Average Filter Frequency Control                 */
                              /* 0=Filter cutoff freq set by datarate bits DR[1:0]*/
                              /* 1=Filter cutoff freq set by AFF bits AFF[1:0]    */

  #define ECHO_AFF_VALUE   0              /* Average Filter Frequency             */
                                          /* Can  ignore if ECHO_AFFC is set to 0 */
                                          /* 0 = 0.5KHz                           */
                                          /* 1 = 1KHz                             */
                                          /* 2 = 2KHz                             */
                                          /* 3 = 4KHz                             */
                          
                          
  #define ECHO_EDD_VALUE  1               /* Envelope Detector Decay rate control */
                                          /* Sets decay rate of envelope detector */
                                          /* 0 = slow decay for minimum ripple    */
                                          /* 1 = fast decay                       */                                                

  #define ECHO_IFLA_VALUE 0               /* IF Level Attenuation                 */
                                          /* 0 = no attenuation                   */
                                          /* 1= 20dB attenuation(in OOK mode only)*/



#endif





/************************************************/
/*                                              */
/*       Properties for  BANK B in MC33696      */
/*                                              */                                              
/************************************************/

/* --- Echo Bank B Enable ------------           */
#define ECHO_BANK_B_EN     1 /* Switch if you want use Bank B in MC33696 */
                          /* 0 - Bank B disable             */
                          /* 1 - Bank B enable              */
                            
#if ECHO_BANK_B_EN == 1
  /* --- Echo modulation parameters ---------												*/
  #define ECHO_MODE_VALUE_B			ECHO_OOK		/* ECHO_OOK = OOK reception				*/
  												/* ECHO_FSK = FSK reception				*/
  #define ECHO_MODE_DSREF_B		1				/* Select the data slicer reference in	*/
  												/* OOK mode: 0 = fixed, 1 = adaptive	*/
  												/* Can delete/ignore if using FSK		*/
  												
  #define ECHO_BAND_VALUE_B			ECHO_F434MHz	/* ECHO_F304MHz, ECHO_F315MHz,			*/
  												/* ECHO_F434MHz, ECHO_F868MHz,			*/
  												/* or ECHO_F916MHz						*/

  #define ECHO_DATA_RATE_B	  	2400			/* Set Echo data rate in Hz (before		*/
  												/* Manchester encoding)					*/


  /* --- ID and Header set up ---------------												*/
  #define ECHO_ID_LENGTH_B			6				/* 6 Length of ID (2,4,5,6 or 8 bits)		*/
  #define ECHO_ID_VALUE_B			0xc8 			/* 11 ID word recognised by Echo			*/

  #define ECHO_HEADER_LENGTH_B		4				/* Length of header (1,2,4,6 bits)		*/
  #define ECHO_HEADER_VALUE_B		0x06			/* Header word recognised by Echo (must	*/
  												/* not be present in Preamble/ID)		*/



  /* These values are calculated from the Echo datasheet or supporting driver spreadsheet */
  #define ECHO_RXON_VALUE_B			15				/* On time:  1->15						*/
  #define ECHO_RXOFF_VALUE_B		1				/* Off time: 0->7						*/

  /* --- Misc -------------------------------												*/
  #define ECHO_AFFC_VALUE_B  0  /* Average Filter Frequency Control                 */
                              /* 0=Filter cutoff freq set by datarate bits DR[1:0]*/
                              /* 1=Filter cutoff freq set by AFF bits AFF[1:0]    */

  #define ECHO_AFF_VALUE_B   0              /* Average Filter Frequency             */
                                          /* Can  ignore if ECHO_AFFC is set to 0 */
                                          /* 0 = 0.5KHz                           */
                                          /* 1 = 1KHz                             */
                                          /* 2 = 2KHz                             */
                                          /* 3 = 4KHz                             */
                          
                          
  #define ECHO_EDD_VALUE_B  1               /* Envelope Detector Decay rate control */
                                          /* Sets decay rate of envelope detector */
                                          /* 0 = slow decay for minimum ripple    */
                                          /* 1 = fast decay                       */                                                

  #define ECHO_IFLA_VALUE_B 0               /* IF Level Attenuation                 */
                                          /* 0 = no attenuation                   */
                                          /* 1= 20dB attenuation(in OOK mode only)*/



#endif




/****************************************************************************************/
/* These may be omitted depending on the hardware setup									*/
#ifdef __HCS08__
 /* Edit this part if you have project with HCS08 mcu */
 
//#define ECHO_RSSIC				PTAD_PTAD2	  	/* Define pin used for RSSIC			*/
//#define ECHO_RSSIC_DDR		PTADD_PTADD2    /* If hardwired,delete #defines			*/

#define ECHO_STROBE			PTCD_PTCD5			/* Define pin used for Strobe			*/
#define ECHO_STROBE_DDR		PTCDD_PTCDD5		/* If hardwired,delete #defines			*/

/* These are required for use with Motorola's rf modules								*/
//#define ECHO_ENABLEPA		PTAD_PTAD4			/* Define pin used for Power amp enable	*/
//#define ECHO_ENABLEPA_DDR	PTADD_PTADD4		/* If hardwired, delete #defines		*/

//#define ECHO_ENABLELNA		PTAD_PTAD5			/* Define pin used for LNA				*/
//#define ECHO_ENABLELNA_DDR	PTADD_PTADD5		/* If hardwired,delete #defines			*/

#else
 /* Edit this part if you have project with HC08 mcu */
 
#define ECHO_RSSIC				PTD_PTD2	  	/* Define pin used for RSSIC			*/
#define ECHO_RSSIC_DDR		DDRD_DDRD2    /* If hardwired, delete #defines		*/

#define ECHO_STROBE			PTA_PTA3			/* Define pin used for Strobe			*/
#define ECHO_STROBE_DDR		DDRA_DDRA3		/* If hardwired,delete #defines			*/

/* These are required for use with Motorola's rf modules								*/
//#define ECHO_ENABLEPA		PTED_PTED4			/* Define pin used for Power amp enable	*/
//#define ECHO_ENABLEPA_DDR	PTEDD_PTEDD4		/* If hardwired, delete #defines		*/

//#define ECHO_ENABLELNA		PTED_PTED5			/* Define pin used for LNA				*/
//#define ECHO_ENABLELNA_DDR	PTEDD_PTEDD5		/* If hardwired,delete #defines			*/
  
#endif
/****************************************************************************************/

























/****************************************************************************************/
/* This defines default values for  #defines in the Echo.h , or prints errors if		*/
/* missing or incorrect values have been chosen											*/
/*						DO NOT EDIT THIS SECTION!!										*/

#ifndef ECHO_CONFB
#error "You must #define symbol ECHO_CONFB in Echo.H header file"
#endif

#ifndef ECHO_CONFB_DDR
#error "You must #define symbol ECHO_CONFB_DDR in Echo.H header file"
#endif

#ifndef ECHO_SEB
#error "You must #define symbol ECHO_SEB in Echo.H header file"
#endif

#ifndef ECHO_SEB_DDR
#error "You must #define symbol ECHO_SEB_DDR in Echo.H header file"
#endif




#ifndef ECHO_BANK_A_EN
#error "You must #define symbol ECHO_BANK_A_EN in Echo.H header file"
#endif

#ifndef ECHO_BANK_B_EN
#error "You must #define symbol ECHO_BANK_B_EN in Echo.H header file"
#endif

#if ECHO_BANK_A_EN == 0 && ECHO_BANK_B_EN == 0
  #error "You must set to 1 ECHO_BANK_A_EN or ECHO_BANK_B_EN or both in Echo.H header file"
#endif

#if ECHO_BANK_A_EN ==1 && ECHO_BANK_B_EN ==1
  #ifndef ECHO_AUTO_SWITCH
  #error "You must #define symbol ECHO_AUTO_SWITCH in Echo.H header file"
  #endif

  #if ECHO_AUTO_SWITCH > 1 && ECHO_AUTO_SWITCH < 0
  #error "ECHO_AUTO_SWITCH in Echo.h must be 0 or 1"
  #endif
#endif

#ifndef ECHO_SPI_ADDRESS
#error "You must #define symbol ECHO_SPI_ADDRESS in Echo.H header file"
#endif

#ifndef ECHO_SPI_CLOCK_SPEED
#error "You must #define symbol ECHO_SPI_CLOCK_SPEED in Echo.H header file"
#endif



#ifndef ECHO_MAX_DATA_SIZE
#error "You must #define symbol ECHO_MAX_DATA_SIZE in Echo.H header file"
#endif

#if ECHO_MAX_DATA_SIZE > 127
#error "ECHO_MAX_DATA_SIZE in Echo.h must be in range 0- 127"
#endif

#ifndef ECHO_RX_BUF_COUNT
#error "You must #define symbol ECHO_RX_BUF_COUNT in Echo.H header file"
#endif

#if ECHO_RX_BUF_COUNT < 1
#error "ECHO_RX_BUF_COUNT in Echo.H must be 1 or more"
#endif


#if ECHO_BANK_A_EN == 1
  #ifndef ECHO_MODE_VALUE
  #error "You must #define symbol ECHO_MODE_VALUE in Echo.H header file"
  #endif

  #if ECHO_MODE_VALUE == ECHO_OOK
  	#ifndef ECHO_MODE_DSREF
  	#error "You must #define symbol ECHO_MODE_DSREF when using OOK modulation in Echo.H header file"
  	#endif
  	
  	#if ECHO_MODE_DSREF != 0 && ECHO_MODE_DSREF != 1
  	#error "ECHO_MODE_DSREF must be 1 or 0 in Echo.h header file"
  	#endif
  #else
  	#if ECHO_MODE_VALUE == ECHO_FSK
  		// It's ok so do nothing
  	#else
  		#error "You must set ECHO_MODE_VALUE to ECHO_OOK or ECHO_FSK in Echo.H header file"
  	#endif
  #endif



  #ifndef ECHO_BAND_VALUE
  	#error "You must #define symbol ECHO_BAND_VALUE in Echo.H header file"
  #endif

  #if ECHO_BAND_VALUE == ECHO_F315MHz
  	#define ECHO_LOF_CF_VALUE	0x80
  #elif ECHO_BAND_VALUE == ECHO_F434MHz
  	#define ECHO_LOF_CF_VALUE	0x50	//0xD0
  #elif ECHO_BAND_VALUE == ECHO_F868MHz
  	#define ECHO_LOF_CF_VALUE	0xF0
  #elif ECHO_BAND_VALUE == ECHO_F304MHz
  	#define ECHO_LOF_CF_VALUE	0x00
  #elif ECHO_BAND_VALUE == ECHO_F916MHz
  	#define ECHO_LOF_CF_VALUE	0xF0
  #else
  	#error "You must set ECHO_BAND_VALUE to ECHO_F304MHz, ECHO_F315MHz, ECHO_F434MHz, ECHO_F868MHz or ECHO_F916MHz in Echo.H header file"
  #endif



  #ifndef ECHO_DATA_RATE
  #error "You must #define symbol ECHO_DATA_RATE in Echo.h header file"
  #endif

  #if ECHO_DATA_RATE >= 2000 && ECHO_DATA_RATE <= 2800
  	#define ECHO_DR_VALUE	0
  #elif ECHO_DATA_RATE >= 4000 && ECHO_DATA_RATE <= 5600
  	#define ECHO_DR_VALUE	1
  #elif ECHO_DATA_RATE >= 8000 && ECHO_DATA_RATE <= 10600
  	#define ECHO_DR_VALUE	2
  #elif ECHO_DATA_RATE >= 16000 && ECHO_DATA_RATE <= 22400
  	#define ECHO_DR_VALUE	3
  #else
  	#error "ECHO_DATA_RATE must be between 2000-2800, 4000-5600, 8000-10600 or 16000-22400 kbaud in Echo.h header file"
  #endif



  #ifndef ECHO_ID_LENGTH
  #error "You must #define symbol ECHO_ID_LENGTH in Echo.H header file"
  #endif

  #ifndef ECHO_ID_VALUE
  #error "You must #define symbol ECHO_ID_VALUE in Echo.H header file"
  #endif

  #if   ECHO_ID_LENGTH == 2
  							#define ECHO_IDL 0
  #elif ECHO_ID_LENGTH == 4
  							#define ECHO_IDL 1
  #elif ECHO_ID_LENGTH == 5
  							#define ECHO_IDL 2
  #elif ECHO_ID_LENGTH == 6
  							#define ECHO_IDL 3
  #elif ECHO_ID_LENGTH == 8						/* When ID length=8, driver sends 8 bits ID; max number	*/
  							#define ECHO_IDL 3	/* ID bits in Echos register is still only 6. 8 bit ID	*/
  #else											/* sends can be used for compatibility with Romeo/Tango	*/
  	#error "ECHO_ID_LENGTH must be 2, 4, 5, 6 or 8 bits long"
  #endif



  #ifndef ECHO_HEADER_LENGTH
  #error "You must #define symbol ECHO_HEADER_LENGTH in Echo.H header file"
  #endif

  #ifndef ECHO_HEADER_VALUE
  #error "You must #define symbol ECHO_HEADER_VALUE in Echo.H header file"
  #endif

  #if   ECHO_HEADER_LENGTH == 1
  								#define ECHO_HDL 0
  #elif ECHO_HEADER_LENGTH == 2
  								#define ECHO_HDL 1
  #elif ECHO_HEADER_LENGTH == 4
  								#define ECHO_HDL 2
  #elif ECHO_HEADER_LENGTH == 6
  								#define ECHO_HDL 3
  #else
  	#error "ECHO_HEADER_LENGTH must be 1, 2, 4 or 6 bits long"
  #endif

  #ifndef ECHO_RXON_VALUE
  #error "You must #define symbol ECHO_RXON_VALUE in Echo.H header file"
  #endif

  #ifndef ECHO_RXOFF_VALUE
  #error "You must #define symbol ECHO_RXOFF_VALUE in Echo.H header file"
  #endif

  #if ECHO_RXON_VALUE < 1 || ECHO_RXON_VALUE > 15
  #error "ECHO_RXON_VALUE must be between 1 and 15 inclusive in Echo.h header file"
  #endif

  #if ECHO_RXOFF_VALUE < 0 || ECHO_RXOFF_VALUE > 7
  #error "ECHO_RXOFF_VALUE must be between 0 and 7 inclusive in Echo.h header file"
  #endif

  #ifndef ECHO_AFFC_VALUE
  #error "You must #define symbol ECHO_AFFC_VALUE in Echo.H header file"
  #endif
  
  #if ECHO_AFFC_VALUE != 0 && ECHO_AFFC_VALUE != 1
  #error "ECHO_AFFC_VALUE must be 1 or 0 in Echo.h header file"
  #endif
  
  #if ECHO_AFFC_VALUE == 1
    #ifndef ECHO_AFF_VALUE
    #error "You must #define symbol ECHO_AFF_VALUE in Echo.H header file"
    #endif
    
    #if   ECHO_AFF_VALUE == 0
    								#define ECHO_AFF 0x00
    #elif ECHO_AFF_VALUE == 1
    								#define ECHO_AFF 0x40
    #elif ECHO_AFF_VALUE == 2
    								#define ECHO_AFF 0x80
    #elif ECHO_AFF_VALUE == 3
    								#define ECHO_AFF 0xC0
    #else
    	#error "ECHO_AFF_VALUE must be 0, 1, 2 or 3."
    #endif    
  #else 
    #define ECHO_AFF 0x00
  #endif
  
  #ifndef ECHO_EDD_VALUE
  #error "You must #define symbol ECHO_EDD_VALUE in Echo.H header file"
  #endif
  
  #if ECHO_EDD_VALUE != 0 && ECHO_EDD_VALUE != 1
  #error "ECHO_EDD_VALUE must be 1 or 0 in Echo.h header file"
  #endif 
  
  #ifndef ECHO_IFLA_VALUE
  #error "You must #define symbol ECHO_IFLA_VALUE in Echo.H header file"
  #endif
  
  #if ECHO_IFLA_VALUE != 0 && ECHO_IFLA_VALUE != 1
  #error "ECHO_IFLA_VALUE must be 1 or 0 in Echo.h header file"
  #endif

#endif

#if ECHO_BANK_B_EN == 1
  #ifndef ECHO_MODE_VALUE_B
  #error "You must #define symbol ECHO_MODE_VALUE_B in Echo.H header file"
  #endif

  #if ECHO_MODE_VALUE_B == ECHO_OOK
  	#ifndef ECHO_MODE_DSREF_B
  	#error "You must #define symbol ECHO_MODE_DSREF_B when using OOK modulation in Echo.H header file"
  	#endif
  	
  	#if ECHO_MODE_DSREF_B != 0 && ECHO_MODE_DSREF_B != 1
  	#error "ECHO_MODE_DSREF_B must be 1 or 0 in Echo.h header file"
  	#endif
  #else
  	#if ECHO_MODE_VALUE_B == ECHO_FSK
  		// It's ok so do nothing
  	#else
  		#error "You must set ECHO_MODE_VALUE_B to ECHO_OOK or ECHO_FSK in Echo.H header file"
  	#endif
  #endif



  #ifndef ECHO_BAND_VALUE_B
  	#error "You must #define symbol ECHO_BAND_VALUE_B in Echo.H header file"
  #endif

  #if ECHO_BAND_VALUE_B == ECHO_F315MHz
  	#define ECHO_LOF_CF_VALUE_B	0x80
  #elif ECHO_BAND_VALUE_B == ECHO_F434MHz
  	#define ECHO_LOF_CF_VALUE_B	0x50	//0xD0
  #elif ECHO_BAND_VALUE_B == ECHO_F868MHz
  	#define ECHO_LOF_CF_VALUE_B	0xF0
  #elif ECHO_BAND_VALUE_B == ECHO_F304MHz
  	#define ECHO_LOF_CF_VALUE_B	0x00
  #elif ECHO_BAND_VALUE_B == ECHO_F916MHz
  	#define ECHO_LOF_CF_VALUE_B	0xF0
  #else
  	#error "You must set ECHO_BAND_VALUE_B to ECHO_F304MHz, ECHO_F315MHz, ECHO_F434MHz, ECHO_F868MHz or ECHO_F916MHz in Echo.H header file"
  #endif



  #ifndef ECHO_DATA_RATE_B
  #error "You must #define symbol ECHO_DATA_RATE_B in Echo.h header file"
  #endif

  #if ECHO_DATA_RATE_B >= 2000 && ECHO_DATA_RATE_B <= 2800
  	#define ECHO_DR_VALUE_B	0
  #elif ECHO_DATA_RATE_B >= 4000 && ECHO_DATA_RATE_B <= 5600
  	#define ECHO_DR_VALUE_B	1
  #elif ECHO_DATA_RATE_B >= 8000 && ECHO_DATA_RATE_B <= 10600
  	#define ECHO_DR_VALUE_B	2
  #elif ECHO_DATA_RATE_B >= 16000 && ECHO_DATA_RATE_B <= 22400
  	#define ECHO_DR_VALUE_B	3
  #else
  	#error "ECHO_DATA_RATE_B must be between 2000-2800, 4000-5600, 8000-10600 or 16000-22400 kbaud in Echo.h header file"
  #endif



  #ifndef ECHO_ID_LENGTH_B
  #error "You must #define symbol ECHO_ID_LENGTH_B in Echo.H header file"
  #endif

  #ifndef ECHO_ID_VALUE_B
  #error "You must #define symbol ECHO_ID_VALUE_B in Echo.H header file"
  #endif

  #if   ECHO_ID_LENGTH_B == 2
  							#define ECHO_IDL_B 0
  #elif ECHO_ID_LENGTH_B == 4
  							#define ECHO_IDL_B 1
  #elif ECHO_ID_LENGTH_B == 5
  							#define ECHO_IDL_B 2
  #elif ECHO_ID_LENGTH_B == 6
  							#define ECHO_IDL_B 3
  #elif ECHO_ID_LENGTH_B == 8						/* When ID length=8, driver sends 8 bits ID; max number	*/
  							#define ECHO_IDL_B 3	/* ID bits in Echos register is still only 6. 8 bit ID	*/
  #else											/* sends can be used for compatibility with Romeo/Tango	*/
  	#error "ECHO_ID_LENGTH_B must be 2, 4, 5, 6 or 8 bits long"
  #endif



  #ifndef ECHO_HEADER_LENGTH_B
  #error "You must #define symbol ECHO_HEADER_LENGTH_B in Echo.H header file"
  #endif

  #ifndef ECHO_HEADER_VALUE_B
  #error "You must #define symbol ECHO_HEADER_VALUE_B in Echo.H header file"
  #endif

  #if   ECHO_HEADER_LENGTH_B == 1
  								#define ECHO_HDL_B 0
  #elif ECHO_HEADER_LENGTH_B == 2
  								#define ECHO_HDL_B 1
  #elif ECHO_HEADER_LENGTH_B == 4
  								#define ECHO_HDL_B 2
  #elif ECHO_HEADER_LENGTH_B == 6
  								#define ECHO_HDL_B 3
  #else
  	#error "ECHO_HEADER_LENGTH_B must be 1, 2, 4 or 6 bits long"
  #endif

  #ifndef ECHO_RXON_VALUE_B
  #error "You must #define symbol ECHO_RXON_VALUE_B in Echo.H header file"
  #endif

  #ifndef ECHO_RXOFF_VALUE_B
  #error "You must #define symbol ECHO_RXOFF_VALUE_B in Echo.H header file"
  #endif

  #if ECHO_RXON_VALUE_B < 1 || ECHO_RXON_VALUE_B > 15
  #error "ECHO_RXON_VALUE_B must be between 1 and 15 inclusive in Echo.h header file"
  #endif

  #if ECHO_RXOFF_VALUE_B < 0 || ECHO_RXOFF_VALUE_B > 7
  #error "ECHO_RXOFF_VALUE_B must be between 0 and 7 inclusive in Echo.h header file"
  #endif

  #ifndef ECHO_AFFC_VALUE_B
  #error "You must #define symbol ECHO_AFFC_VALUE_B in Echo.H header file"
  #endif
  
  #if ECHO_AFFC_VALUE_B != 0 && ECHO_AFFC_VALUE_B != 1
  #error "ECHO_AFFC_VALUE_B must be 1 or 0 in Echo.h header file"
  #endif
  
  #if ECHO_AFFC_VALUE_B == 1
    #ifndef ECHO_AFF_VALUE_B
    #error "You must #define symbol ECHO_AFF_VALUE_B in Echo.H header file"
    #endif
    
    #if   ECHO_AFF_VALUE_B == 0
    								#define ECHO_AFF_B 0x00
    #elif ECHO_AFF_VALUE_B == 1
    								#define ECHO_AFF_B 0x40
    #elif ECHO_AFF_VALUE_B == 2
    								#define ECHO_AFF_B 0x80
    #elif ECHO_AFF_VALUE_B == 3
    								#define ECHO_AFF_B 0xC0
    #else
    	#error "ECHO_AFF_VALUE_B must be 0, 1, 2 or 3."
    #endif    
  #else 
    #define ECHO_AFF_B 0x00
  #endif
  
  #ifndef ECHO_EDD_VALUE_B
  #error "You must #define symbol ECHO_EDD_VALUE_B in Echo.H header file"
  #endif
  
  #if ECHO_EDD_VALUE_B != 0 && ECHO_EDD_VALUE_B != 1
  #error "ECHO_EDD_VALUE_B must be 1 or 0 in Echo.h header file"
  #endif 
  
  #ifndef ECHO_IFLA_VALUE_B
  #error "You must #define symbol ECHO_IFLA_VALUE_B in Echo.H header file"
  #endif
  
  #if ECHO_IFLA_VALUE_B != 0 && ECHO_IFLA_VALUE_B != 1
  #error "ECHO_IFLA_VALUE_B must be 1 or 0 in Echo.h header file"
  #endif

#endif

#if ECHO_BANK_A_EN == 1 && ECHO_BANK_B_EN == 1
  #if ECHO_DATA_RATE > ECHO_DATA_RATE_B
    #define ECHO_TIMEOUT_TIME_TMP (ECHO_RX_TIMEOUT_BITS * (ECHO_DATA_RATE / ECHO_DATA_RATE_B))
    #define ECHO_FASTER_BANK ECHO_BANK_A   
  #else
    #define ECHO_TIMEOUT_TIME_TMP (ECHO_RX_TIMEOUT_BITS * (ECHO_DATA_RATE_B / ECHO_DATA_RATE))
    #define ECHO_FASTER_BANK ECHO_BANK_B
  #endif
  
  #if (ECHO_TIMEOUT_TIME_TMP > 0xFF)
    #define ECHO_TIMEOUT_TIME 0xFF
  #else
    #define ECHO_TIMEOUT_TIME ECHO_TIMEOUT_TIME_TMP
  #endif
#endif

#ifndef ECHO_SOE_VALUE
#error "You must #define symbol ECHO_SOE_VALUE in Echo.H header file"
#endif

#if ECHO_SOE_VALUE != 0 && ECHO_SOE_VALUE != 1
#error "ECHO_SOE_VALUE must be 1 or 0 in Echo.h header file"
#endif



#ifndef ECHO_TIMER_ADDRESS
#error "You must #define symbol ECHO_TIMER_ADDRESS in Echo.H header file"
#endif

#ifndef ECHO_TIMER_CHANNEL
#error "You must #define symbol ECHO_TIMER_CHANNEL in Echo.H header file"
#endif


#ifndef ECHO_TIMER_CLOCK_SOURCE
#error  "You must #define symbol ECHO_TIMER_CLOCK_SOURCE in Echo.h header file"
#endif

#ifndef ECHO_USE_DATACLK
#error "You must #define symbol ECHO_USE_DATACLK in Echo.h header file"
#endif

#if ECHO_USE_DATACLK != 0 && ECHO_USE_DATACLK != 1
#error "ECHO_USE_DATACLK must be 1 or 0 in Echo.h header file"
#endif

#ifndef ECHO_TIMER_CLOCK_SPEED
#error  "You must #define symbol ECHO_TIMER_CLOCK_SPEED in Echo.h header file"
#endif


#ifndef ECHO_TIMER_PRESCALE
#error "You must #define symbol ECHO_TIMER_PRESCALE in Echo.h header file"
#endif



#ifndef ECHO_CRYSTAL_FREQUENCY
#error "You must #define symbol ECHO_CRYSTAL_FREQUENCY in Echo.h header file"
#endif







#ifndef ECHO_SWITCH_LEVEL
#error "You must #define symbol ECHO_SWITCH_LEVEL in Echo.h header file"
#endif

#if ECHO_SWITCH_LEVEL != 0 && ECHO_SWITCH_LEVEL != 1
#error "ECHO_SWITCH_LEVEL must be 1 or 0 in Echo.h header file"
#endif


#ifndef ECHO_LVD_ENABLE
#error "You must #define symbol ECHO_LVD_ENABLE in Echo.h header file"
#endif

#if ECHO_LVD_ENABLE != 0 && ECHO_LVD_ENABLE != 1
#error "ECHO_LVD_ENABLE must be 1 or 0 in Echo.h header file"
#endif



/* --- SPI configuration ------------------												*/
/* ----------------------------------------												*/
#ifdef __HCS08__
/* Register address offsets for normal HCS08 SPI										*/
#define ECHO_SPIC1 *(volatile byte *)(ECHO_SPI_ADDRESS+0) 	/* SPI Ctrl reg #1			*/
#define ECHO_SPIC2 *(volatile byte *)(ECHO_SPI_ADDRESS+1) 	/* SPI Ctrl reg #2			*/
#define ECHO_SPIBR *(volatile byte *)(ECHO_SPI_ADDRESS+2) 	/* SPI Buad rate reg		*/
#define ECHO_SPIS  *(volatile byte *)(ECHO_SPI_ADDRESS+3) 	/* SPI Status reg			*/
#define ECHO_SPID  *(volatile byte *)(ECHO_SPI_ADDRESS+5) 	/* SPI Data reg				*/

#define ECHO_SPIC1_SPIE	0x80						/* SPI Rx Interrupt enable bit mask	*/
#define ECHO_SPIC1_SPE	0x40						/* SPI module enable bit mask		*/
#define ECHO_SPIC1_MSTR	0x10						/* SPI master/slave mode bit mask	*/

#define ECHO_SPIS_SPRF	0x80						/* SPI read buffer full bit mask	*/
#define ECHO_SPIS_SPTEF	0x20						/* SPI Tx buffer empty bit mask		*/


/* SPI baud rate divider																*/
/* Chooses appropriate baud rate divisor to provide max comms speed to Echo				*/
#define ECHO_MAX_SPI_SPEED		615000				/* Tsclk = 1us (minimum)			*/

#define ECHO_SPI_BAUD_RATE_PRESCALER	1			/* 0 => divide by 1 (see datasheet)	*/
													/* Can set this up if necessary		*/

#if (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 2
    #define ECHO_SPI_BAUD_RATE_DIVISOR  0

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 4
    #define ECHO_SPI_BAUD_RATE_DIVISOR  1

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 8
    #define ECHO_SPI_BAUD_RATE_DIVISOR  2

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 16
    #define ECHO_SPI_BAUD_RATE_DIVISOR  3

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 32
    #define ECHO_SPI_BAUD_RATE_DIVISOR  4

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 64
    #define ECHO_SPI_BAUD_RATE_DIVISOR  5

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 128
    #define ECHO_SPI_BAUD_RATE_DIVISOR  6

#elif (ECHO_SPI_CLOCK_SPEED/((ECHO_SPI_BAUD_RATE_PRESCALER+1)*ECHO_MAX_SPI_SPEED)) <= 256
    #define ECHO_SPI_BAUD_RATE_DIVISOR  7

#else
	#error "MCU SPI Baud Rate too high: increase ECHO_SPI_BAUD_RATE_PRESCALER in header file Echo.h"

#endif

#else
     /* Good place for HC08 code */
 /* Register address offsets for normal HCS08 SPI										*/
#define ECHO_SPIC1 *(volatile byte *)(ECHO_SPI_ADDRESS+0) 	/* SPI Ctrl reg 			*/
#define ECHO_SPIS  *(volatile byte *)(ECHO_SPI_ADDRESS+1) 	/* SPI Status and control reg			*/
#define ECHO_SPID  *(volatile byte *)(ECHO_SPI_ADDRESS+2) 	/* SPI Data reg				*/

#define ECHO_SPIC1_SPIE	0x80						/* SPI Rx Interrupt enable bit mask	*/
#define ECHO_SPIC1_SPE	0x02						/* SPI module enable bit mask		*/
#define ECHO_SPIC1_MSTR	0x20						/* SPI master/slave mode bit mask	*/

#define ECHO_SPIS_SPRF	0x80						/* SPI read buffer full bit mask	*/
#define ECHO_SPIS_SPTEF	0x08						/* SPI Tx buffer empty bit mask		*/

/* SPI baud rate divider																*/
 /* Chooses appropriate baud rate divisor to provide max comms speed to Echo				*/
 #define ECHO_MAX_SPI_SPEED		615000				/* Tsclk = 1us (minimum)			*/
 
 #if (ECHO_SPI_CLOCK_SPEED/ECHO_MAX_SPI_SPEED) <= 2
     #define ECHO_SPI_BAUD_RATE_DIVISOR  0
 #elif (ECHO_SPI_CLOCK_SPEED/ECHO_MAX_SPI_SPEED) <= 8
     #define ECHO_SPI_BAUD_RATE_DIVISOR  1
 #elif (ECHO_SPI_CLOCK_SPEED/ECHO_MAX_SPI_SPEED) <= 32
     #define ECHO_SPI_BAUD_RATE_DIVISOR  2
 #elif (ECHO_SPI_CLOCK_SPEED/ECHO_MAX_SPI_SPEED) <= 128
     #define ECHO_SPI_BAUD_RATE_DIVISOR  3
 #endif 
    
#endif

/* Enable/disable Data Manager	!! DATA MANAGER ALWAYS USED IN THIS VERSION !!			*/
#define ECHO_DME_VALUE     1					/* 0 = Data manager disabled			*/
												/* 1 = Data manager enabled				*/


/* --- Timer configuration ----------------												*/
/* ----------------------------------------												*/

#ifdef __HCS08__
/* Timer register offsets */
/* Register address offsets for normal S08 timer */
#define ECHO_TPMxSC  	*(volatile byte *)(ECHO_TIMER_ADDRESS+0) /* Tmr status/ctrl		*/
#define ECHO_TPMxCNTH	*(volatile byte *)(ECHO_TIMER_ADDRESS+1) /* Timer counter H		*/
#define ECHO_TPMxCNTL	*(volatile byte *)(ECHO_TIMER_ADDRESS+2) /* Timer counter L		*/
#define ECHO_TPMxMODH	*(volatile byte *)(ECHO_TIMER_ADDRESS+3) /* Timer modulus H		*/
#define ECHO_TPMxMODL	*(volatile byte *)(ECHO_TIMER_ADDRESS+4) /* Timer modulus L		*/

/* Registers for each timer channel */
#define ECHO_TPMxCxSC	*(volatile byte *)(ECHO_TIMER_ADDRESS+5+(3*ECHO_TIMER_CHANNEL)+0)
#define ECHO_TPMxCxVH	*(volatile byte *)(ECHO_TIMER_ADDRESS+5+(3*ECHO_TIMER_CHANNEL)+1)
#define ECHO_TPMxCxVL	*(volatile byte *)(ECHO_TIMER_ADDRESS+5+(3*ECHO_TIMER_CHANNEL)+2)

/* Timer control reg masks */
#define ECHO_TIMER_ON	(ECHO_TIMER_CLOCK_SOURCE*8)		/* OR this value to timer		*/
														/* control reg to enable clock	*/
#define ECHO_TIMER_OFF	0xE7							/* AND this value to timer		*/
														/* control reg to disable clock	*/

#define ECHO_TIMER_PIN_OFF		  0x00			/* Turn off interrupts and channel pin	*/

#define ECHO_COMPARE_NO_OUTPUT	0x50			/* Output pin disabled, interrupts on	*/
#define ECHO_CLEAR_ON_COMPARE	  0x58			/* Output a 0 NRZ						*/
#define ECHO_SET_ON_COMPARE		  0x5C			/* Output a 1 NRZ						*/
#define ECHO_PWM_ZERO			      0x64			/* PWM Low-True  => _| (0 Manchester)	*/
#define ECHO_PWM_ONE			      0x68			/* PWM High-True => |_ (1 Manchester)	*/

#define ECHO_TPMxCxSC_CHnIE		  0x40			/* Channel interrupt enable bit mask	*/
#define ECHO_TPMxCxSC_CHnF		  0x80			/* Channel flag, read/reset to clear int*/


/* Miscellaneous timer calculations														*/
#if ECHO_TIMER_CLOCK_SOURCE == 3
	#define ECHO_TIMER_CLK_IN_CHANNEL	0		/* Timer channel used for clk in		*/
												/* (usually timer ch 0 on HCS08)		*/
												/* Delete if not using clk input		*/
#endif

#else
     /* Good place for HC08 code */
  /* Timer register offsets */
/* Register address offsets for normal S08 timer */
#define ECHO_TPMxSC  	*(volatile byte *)(ECHO_TIMER_ADDRESS+0) /* Tmr status/ctrl		*/
#define ECHO_TPMxCNTH	*(volatile byte *)(ECHO_TIMER_ADDRESS+2) /* Timer counter H		*/
#define ECHO_TPMxCNTL	*(volatile byte *)(ECHO_TIMER_ADDRESS+3) /* Timer counter L		*/
#define ECHO_TPMxMODH	*(volatile byte *)(ECHO_TIMER_ADDRESS+4) /* Timer modulus H		*/
#define ECHO_TPMxMODL	*(volatile byte *)(ECHO_TIMER_ADDRESS+5) /* Timer modulus L		*/

/* Registers for each timer channel */
#define ECHO_TPMxCxSC	*(volatile byte *)(ECHO_TIMER_ADDRESS+6+(3*ECHO_TIMER_CHANNEL)+0)
#define ECHO_TPMxCxVH	*(volatile byte *)(ECHO_TIMER_ADDRESS+6+(3*ECHO_TIMER_CHANNEL)+1)
#define ECHO_TPMxCxVL	*(volatile byte *)(ECHO_TIMER_ADDRESS+6+(3*ECHO_TIMER_CHANNEL)+2)

/* Timer control reg masks */
#define ECHO_TIMER_ON 	        0x0df                   /* AND this value to timer control */
                                                      /* reg to enable clock            */
#define ECHO_TIMER_OFF		      0x020   /* OR this value to timer ctrl reg to disable clock */

#define ECHO_TIMER_PIN_OFF		  0x00			/* Turn off interrupts and channel pin	*/

#define ECHO_COMPARE_NO_OUTPUT	0x50			/* Output pin disabled, interrupts on	*/
#define ECHO_CLEAR_ON_COMPARE	  0x58			/* Output a 0 NRZ						*/
#define ECHO_SET_ON_COMPARE		  0x5C			/* Output a 1 NRZ						*/
#define ECHO_PWM_ZERO			      (ECHO_CLEAR_ON_COMPARE | 0x02)	/* PWM Low-True  => _| (0 Manchester)	*/
#define ECHO_PWM_ONE			      (ECHO_SET_ON_COMPARE | 0x02 )		/* PWM High-True => |_ (1 Manchester)	*/
 
#define ECHO_TPMxCxSC_CHnIE		  0x40			/* Channel interrupt enable bit mask	*/
#define ECHO_TPMxCxSC_CHnF		  0x80			/* Channel flag, read/reset to clear int*/


    
#endif

/****************************************************************************************/
/* This part may need changed to include 304MHz and 916MHz bands...						*/
/****************************************************************************************/

#if ECHO_BANK_A_EN == 1
  #if ECHO_BAND_VALUE == ECHO_F315MHz || ECHO_BAND_VALUE == ECHO_F304MHz
  	//#define ECHO_DIGCLK_DIVISOR		30
  	#define ECHO_DATACLK_DIVISOR	60
  #else
  	//#define ECHO_DIGCLK_DIVISOR		40
  	#define ECHO_DATACLK_DIVISOR	80
  #endif
#endif

#if ECHO_BANK_B_EN == 1
  #if ECHO_BAND_VALUE_B == ECHO_F315MHz || ECHO_BAND_VALUE_B == ECHO_F304MHz
  	//#define ECHO_DIGCLK_DIVISOR		30
  	#define ECHO_DATACLK_DIVISOR_B	60
  #else
  	//#define ECHO_DIGCLK_DIVISOR		40
  	#define ECHO_DATACLK_DIVISOR_B	80
  #endif
#endif
/****************************************************************************************/

#define ECHO_TIMER_CLOCK_SPEED_B  ECHO_TIMER_CLOCK_SPEED

#ifdef ECHO_TIMER_CLK_IN_CHANNEL				/* If using an external clock source	*/
	#if ECHO_USE_DATACLK == 1
		#undef ECHO_TIMER_CLOCK_SPEED
		#if ECHO_BANK_A_EN == 1
		  #define ECHO_TIMER_CLOCK_SPEED	(ECHO_CRYSTAL_FREQUENCY/ECHO_DATACLK_DIVISOR)
		#endif
		#undef ECHO_TIMER_CLOCK_SPEED_B
		#if ECHO_BANK_B_EN == 1
		  #define ECHO_TIMER_CLOCK_SPEED_B	(ECHO_CRYSTAL_FREQUENCY/ECHO_DATACLK_DIVISOR_B)
		#endif		  
	#endif
#endif

/* Calculate the modulus and values														*/
#if ECHO_BANK_A_EN == 1
  #define ECHO_TIMER_MODULUS  ((ECHO_TIMER_CLOCK_SPEED/ECHO_DATA_RATE)/ECHO_TIMER_PRESCALE)

  #define ECHO_HALF_TIMER_MODULUS		(ECHO_TIMER_MODULUS/2)

  #define ECHO_MODH	((byte)(ECHO_TIMER_MODULUS/256))
  #define ECHO_MODL	((byte)(ECHO_TIMER_MODULUS%256))

  #define ECHO_COMH	((byte)(ECHO_HALF_TIMER_MODULUS/256))
  #define ECHO_COML	((byte)(ECHO_HALF_TIMER_MODULUS%256))

  /* Number of bit times for greater than 2ms power on delay (2ms => 500Hz)				*/
  #define ECHO_2MS_DELAY  (((ECHO_TIMER_CLOCK_SPEED/500)/ECHO_TIMER_MODULUS)+1)

  /* Number of bit times for 1.2ms Echo config power on delay (1.2ms => 833Hz)		*/
  #define ECHO_1200uS_DELAY  ((ECHO_DATA_RATE/833)+1)

  /* Number of bit times for 500 microsecond Tx->Rx mode switch delay (500uS => 2000Hz)	*/
  #define ECHO_500uS_DELAY	((ECHO_DATA_RATE/2000)+1)

  /* Number of bit-times for a 200 microsecond preamble period (+1 to make sure >200uS)	*/
  /* Also need additional half-bit added because of the way PREAMBLE_1 state is			*/
  /* implemented: last count is cut short to 1/2 bit-time by PWM low true pulse.			*/
  /* Hence, 1 + 1/2 = 3/2 = 7500/5000														*/
  #define ECHO_PREAMBLE_FSK00uS		((ECHO_DATA_RATE+7500)/5000)

#endif

#if ECHO_BANK_B_EN == 1
  #define ECHO_TIMER_MODULUS_B  ((ECHO_TIMER_CLOCK_SPEED_B/ECHO_DATA_RATE_B)/ECHO_TIMER_PRESCALE)

  #define ECHO_HALF_TIMER_MODULUS_B		(ECHO_TIMER_MODULUS_B/2)

  #define ECHO_MODH_B	((byte)(ECHO_TIMER_MODULUS_B/256))
  #define ECHO_MODL_B	((byte)(ECHO_TIMER_MODULUS_B%256))

  #define ECHO_COMH_B	((byte)(ECHO_HALF_TIMER_MODULUS_B/256))
  #define ECHO_COML_B	((byte)(ECHO_HALF_TIMER_MODULUS_B%256))

  /* Number of bit times for greater than 2ms power on delay (2ms => 500Hz)				*/
  #define ECHO_2MS_DELAY_B  (((ECHO_TIMER_CLOCK_SPEED_B/500)/ECHO_TIMER_MODULUS_B)+1)

  /* Number of bit times for 1.2ms Echo config power on delay (1.2ms => 833Hz)		*/
  #define ECHO_1200uS_DELAY_B  ((ECHO_DATA_RATE_B/833)+1)

  /* Number of bit times for 500 microsecond Tx->Rx mode switch delay (500uS => 2000Hz)	*/
  #define ECHO_500uS_DELAY_B	((ECHO_DATA_RATE_B/2000)+1)

  /* Number of bit-times for a 200 microsecond preamble period (+1 to make sure >200uS)	*/
  /* Also need additional half-bit added because of the way PREAMBLE_1 state is			*/
  /* implemented: last count is cut short to 1/2 bit-time by PWM low true pulse.			*/
  /* Hence, 1 + 1/2 = 3/2 = 7500/5000														*/
  #define ECHO_PREAMBLE_FSK00uS_B		((ECHO_DATA_RATE_B+7500)/5000)

#endif



/* --- Echo registers ---------------------												*/
/* ----------------------------------------												*/

#define ECHO_CONFIG1_REG	0
#define ECHO_CONFIG2_REG	1
#define ECHO_CONFIG3_REG	2
#define ECHO_COMMAND_REG	3
#define ECHO_F1_REG			4
#define ECHO_F0_REG			5
#define ECHO_FT2_REG		6
#define ECHO_FT1_REG		7
#define ECHO_FT0_REG		8
#define ECHO_RXONOFF_REG	9
#define ECHO_ID_REG			10
#define ECHO_HEADER_REG		11
#define ECHO_RSSI_REG		12

#define ECHO_REGB_OFFSET 13



/*Register: CONFIG2*/
#define ECHO_BIT_SOE		0x01
#define ECHO_BIT_FRM		0x40
#define ECHO_BIT_TRXE		0x04

/*Register: COMMAND*/
#define ECHO_BIT_BANKS  0x01
#define ECHO_BIT_FAGC		0x02
#define ECHO_BIT_RAGC		0x04
#define ECHO_BIT_RSSIE	0x10
#define ECHO_BIT_MODE		0x20
#define ECHO_BIT_IFLA		0x40



/*  CONFIG1 byte																		*/
/* This macro constructs the CONFIG1 byte												*/
#if ECHO_BANK_A_EN == 1
  #define ECHO_CONFIG1_REG_VALUE	(ECHO_LOF_CF_VALUE | ECHO_SWITCH_LEVEL << 2\
  								| ECHO_LVD_ENABLE << 1 | ECHO_USE_DATACLK)
#endif

#if ECHO_BANK_B_EN == 1
  #define ECHO_CONFIG1_REG_VALUE_B	(ECHO_LOF_CF_VALUE_B | ECHO_SWITCH_LEVEL << 2\
  								| ECHO_LVD_ENABLE << 1 | ECHO_USE_DATACLK)
#endif

/* CONFIG2 byte																			*/
/* This macro constructs the CONFIG2 byte												*/
#if ECHO_BANK_A_EN == 1
  #define ECHO_CONFIG2_REG_VALUE	(ECHO_MODE_DSREF << 7 | ECHO_MODE_VALUE << 5\
  	| ECHO_DR_VALUE << 3 | ECHO_DME_VALUE << 1 | ECHO_SOE_VALUE)
#endif

#if ECHO_BANK_B_EN == 1
  #define ECHO_CONFIG2_REG_VALUE_B	(ECHO_MODE_DSREF_B << 7 | ECHO_MODE_VALUE_B << 5\
  	| ECHO_DR_VALUE_B << 3 | ECHO_DME_VALUE << 1 | ECHO_SOE_VALUE)
#endif


/* CONFIG3 byte - no setup necessary, power/sensitivity controls can be setup post init	*/
#if ECHO_BANK_A_EN ==  1
  #define ECHO_CONFIG3_REG_VALUE	(ECHO_AFF)
#endif

#if ECHO_BANK_B_EN ==  1
  #define ECHO_CONFIG3_REG_VALUE_B	(ECHO_AFF_B)
#endif

#define ECHO_LVDS_BIT 0x10 


/* COMMAND byte - setup to Echo default values											*/
#if ECHO_BANK_A_EN ==  1
  #define ECHO_COMMAND_REG_VALUE	(ECHO_AFFC_VALUE << 7 | ECHO_IFLA_VALUE << 6 | ECHO_EDD_VALUE << 3 )
#endif

#if ECHO_BANK_B_EN ==  1
  #define ECHO_COMMAND_REG_VALUE_B	(ECHO_AFFC_VALUE_B << 7 | ECHO_IFLA_VALUE_B << 6 | ECHO_EDD_VALUE_B << 3 )
#endif


/* F and FT registers - default values													*/
#define ECHO_F1_REG_VALUE		0x48
#define ECHO_F0_REG_VALUE		0x00

#define ECHO_FT2_REG_VALUE		0x70
#define ECHO_FT1_REG_VALUE		0x07
#define ECHO_FT0_REG_VALUE		0x01

/* RXONOFF byte - constructed from RXON and RXOFF											*/
#if ECHO_BANK_A_EN ==  1
  #define ECHO_RXONOFF_REG_VALUE	(ECHO_BIT_BANK | ECHO_RXON_VALUE << 3 | ECHO_RXOFF_VALUE)
#endif

#if ECHO_BANK_B_EN ==  1
  #define ECHO_RXONOFF_REG_VALUE_B	(ECHO_BIT_BANK | ECHO_RXON_VALUE_B << 3 | ECHO_RXOFF_VALUE_B)
#endif

#define ECHO_BIT_BANK 0x80

/* ID byte - constructed from ID length and the ID itself									*/
#if ECHO_BANK_A_EN ==  1  
  #if ECHO_ID_LENGTH == 8
  	#define ECHO_ID_REG_VALUE			(ECHO_IDL << 6 | ((ECHO_ID_VALUE>>2) & 0x3F))
  #else
  	#define ECHO_ID_REG_VALUE			(ECHO_IDL << 6 | (ECHO_ID_VALUE & 0x3F))
  #endif
#endif

#if ECHO_BANK_B_EN ==  1  
  #if ECHO_ID_LENGTH_B == 8
  	#define ECHO_ID_REG_VALUE_B			(ECHO_IDL_B << 6 | ((ECHO_ID_VALUE_B>>2) & 0x3F))
  #else
  	#define ECHO_ID_REG_VALUE_B			(ECHO_IDL_B << 6 | (ECHO_ID_VALUE_B & 0x3F))
  #endif
#endif
  

/* HEADER byte - constructed from Header length and the header itself						*/
#if ECHO_BANK_A_EN ==  1
  #define ECHO_HEADER_REG_VALUE		(ECHO_HDL << 6 | (ECHO_HEADER_VALUE & 0x3F))
#endif

#if ECHO_BANK_B_EN ==  1
  #define ECHO_HEADER_REG_VALUE_B		(ECHO_HDL_B << 6 | (ECHO_HEADER_VALUE_B & 0x3F))
#endif


/* RSSI byte - read only																	*/
#define ECHO_RSSI_REG_VALUE		0x00

/* --- Defines for switching banks --------------*/
#if ECHO_BANK_A_EN == 1 && ECHO_BANK_B_EN == 0
  
  #define ECHO_MODE 0
  #define _ECHO_MODE_VALUE          ECHO_MODE_VALUE
  #define _ECHO_PREAMBLE_FSK00uS      ECHO_PREAMBLE_FSK00uS
  #define _ECHO_MODE_DSREF          ECHO_MODE_DSREF
  #define _ECHO_ID_LENGTH           ECHO_ID_LENGTH
  #define _ECHO_HEADER_VALUE        ECHO_HEADER_VALUE
  #define _ECHO_HEADER_LENGTH       ECHO_HEADER_LENGTH
  #define _ECHO_MODH                ECHO_MODH
  #define _ECHO_MODL                ECHO_MODL
  #define _ECHO_COMH                ECHO_COMH
  #define _ECHO_COML                ECHO_COML
  #define _ECHO_500uS_DELAY         ECHO_500uS_DELAY
  #define _ECHO_RSSIC_TICKS         ECHO_RSSIC_TICKS
  #define _ECHO_TIMER_MODULUS       ECHO_TIMER_MODULUS
  #define _ECHO_1200uS_DELAY        ECHO_1200uS_DELAY
  #define _ECHO_ID_VALUE            ECHO_ID_VALUE
  #define _ECHO_2MS_DELAY           ECHO_2MS_DELAY
  #define _ECHO_ADC_TICKS           ECHO_ADC_TICKS

#else
  
  #define ECHO_PLUS_MODE 0
  typedef struct
  {
    byte echo_mode_value;
    byte echo_mode_dsref;
    byte echo_id_value;
    byte echo_id_length;
    byte echo_header_value;
    byte echo_header_length;    
    byte ECHO_PREAMBLE_FSK00us;
    byte echo_500us_delay;
    byte echo_1200us_delay;
    word echo_2ms_delay;    
    byte echo_modh;
    byte echo_modl;
    byte echo_comh;
    byte echo_coml;
    word echo_timer_modulus;    
  }tSWITCH_BANK_INFO;
  
  #define _ECHO_MODE_VALUE          (p_echoBank->echo_mode_value)         //byte 0 - 4       3 bits
  #define _ECHO_PREAMBLE_FSK00uS      (p_echoBank->ECHO_PREAMBLE_FSK00us)     //byte 0 - 6       3 bits
  #define _ECHO_MODE_DSREF          (p_echoBank->echo_mode_dsref)        //byte 0 - 1       1 bit
  #define _ECHO_ID_LENGTH           (p_echoBank->echo_id_length)          //byte 2 - 8       4 bits
  #define _ECHO_HEADER_VALUE        (p_echoBank->echo_header_value)       //byte 0 - 63      6 bits
  #define _ECHO_HEADER_LENGTH       (p_echoBank->echo_header_length)      //byte 1 - 6       3 bits
  #define _ECHO_MODH                (p_echoBank->echo_modh)               //byte 0 - 255     8 bits
  #define _ECHO_MODL                (p_echoBank->echo_modl)               //byte 0 - 255     8 bits
  #define _ECHO_COMH                (p_echoBank->echo_comh)               //byte 0 - 255     8 bits
  #define _ECHO_COML                (p_echoBank->echo_coml)               //byte 0 - 255     8 bits
  #define _ECHO_500uS_DELAY         (p_echoBank->echo_500us_delay)        //byte 0 - 11      4 bits
  #define _ECHO_TIMER_MODULUS       (p_echoBank->echo_timer_modulus)      //word 0 - 65535   16 bits
  #define _ECHO_1200uS_DELAY        (p_echoBank->echo_1200us_delay)       //byte 0 - 25      5 bits
  #define _ECHO_ID_VALUE            (p_echoBank->echo_id_value)           //byte 0 - 255     8 bits
  #define _ECHO_2MS_DELAY           (p_echoBank->echo_2ms_delay)          //word 0 - 616     10 bits
#endif 


/* --- Status, States and Functions -------												*/
/* ----------------------------------------												*/

#define ECHO_BUFFER_FULL	0x80		/* Mask for Rx buffer full flag					*/
#define ECHO_CHECKSUM_ERROR	0x80		/* Mask for Rx checksum error					*/
#define ECHO_RSSI_BIT		0x20		/* Mask for RSSI present flag					*/
#define ECHO_BANKS_BIT  0x40    /* Mask for determine banks */

typedef union
{
  byte *Ptr;
  word Offset; 
}tECHO_WORD_PTR;

typedef union
{
	byte Byte;
	struct
	{
		byte IDHeaderSelect	:1;	/* 0 = Send ID,		1 = Send Header			*/
		byte CompleteSend		:1;	/* 0 = Single seq,	1 = Complete telegram	*/
		byte IDRepeat			:1; /* 0 = Single ID,	1 = Repeat ID			*/
		byte reserved			:5;
	}Bits;
}tECHO_TXCONFIG;

typedef union
{
	unsigned int Word;
	struct {
		byte ByteH;
		byte ByteL;
	}Bytes;
	struct
	{
		unsigned int EnableDelay	:1;		/* 1 = Echo powering up						*/
		unsigned int ModeSwitchDelay:1;		/* 1 = Echo switching modes					*/
		unsigned int RSSI_Enabled	:1;		/* 1 = RSSI Enabled, 0 = RSSI disabled		*/
		unsigned int RSSI_InProgress:1;		/* 1 = RSSI being read						*/
		unsigned int Error			:1;		/* 1 = Error occured eg config while in Tx	*/
		unsigned int LVD			:1;		/* 1 = Low Voltage Detected					*/
		unsigned int Timeout		:1;		/* 1 = Timeout from an Rx state occured		*/
		unsigned int SwitchMode		:1;		/* Active bank - mainly after receive									*/

		unsigned int Enabled		:1;		/* 1 = Echo enabled, 0 = Echo disabled		*/
		unsigned int Busy			:1;		/* 1 = Echo busy, 0 = Echo idle				*/
		unsigned int MsgReady		:1;		/* 1 = Message waiting, 0 = no message		*/
		unsigned int Tx				:1;		/* 1 = Transmitting							*/
		unsigned int Rx				:1;		/* 1 = Receiving							*/
		unsigned int Checksum		:1; 	/* 1 = Current message has a checksum error	*/
		unsigned int Overrun		:1; 	/* 1 = Msg buffer overrun, last msg lost	*/
		unsigned int Mode			:1;		/* 1 = Transmit Mode, 0 = Receive Mode		*/
	}Bits;
}tECHO_STATUS;


/* Masks for status bits					*/
#define ECHO_STATUS_ENABLED				0x0001
#define ECHO_STATUS_BUSY				0x0002
#define ECHO_STATUS_MSGREADY			0x0004
#define ECHO_STATUS_TX					0x0008
#define ECHO_STATUS_RX					0x0010
#define ECHO_STATUS_CHECKSUM			0x0020
#define ECHO_STATUS_OVERRUN				0x0040
#define ECHO_STATUS_MODE				0x0080
#define ECHO_STATUS_ENABLEDELAY			0x0100
#define ECHO_STATUS_MODESWITCHDELAY		0x0200
#define ECHO_STATUS_RSSI_ENABLED		0x0400
#define ECHO_STATUS_RSSI_INPROGRESS		0x0800
#define ECHO_STATUS_ERROR				0x1000
#define ECHO_STATUS_LVD					0x2000
#define ECHO_STATUS_TIMEOUT				0x4000
#define ECHO_STATUS_BANK				0x8000



/* Driver delay states			*/
#define ECHO_ENABLE_DELAY		0
#define ECHO_TXRX_SWITCH_DELAY	2

/* Tx state machine states	*/
#define ECHO_STARTUP		3
#define ECHO_RXTX_SWITCH	1
#define ECHO_PREAMBLE_OOK		4
#define ECHO_PREAMBLE_FSK		5
#define ECHO_SENDID			6
#define ECHO_SENDHEADER		25
#define ECHO_SENDDATA		7
#define ECHO_SENDCHECKSUM	20
#define ECHO_EXTRA_BIT		8
#define ECHO_EOM_1			9
#define ECHO_EOM_2			10
#define ECHO_SWITCHBACK		17
#define ECHO_END_NOSWITCH	19
#define ECHO_END			11
#define ECHO_WAIT			18

/* Rx state machine states	*/
#define ECHO_READY			12
#define ECHO_READ_DATA		13
#define ECHO_LAST_BYTE		14
#define ECHO_READ_RSSI_1	15
#define ECHO_READ_RSSI_2	16
#define ECHO_READ_BANK_1   26
#define ECHO_READ_BANK_2   27

#define ECHO_CONFIG_DELAY	21
#define ECHO_DO_CONFIG		22


/* Function prototypes		*/
void Echo_Initialize(void);

void Echo_Enable(void);
void Echo_Disable(void);

tECHO_STATUS Echo_DriverStatus(void);

void Echo_ClearError(void);

void Echo_SendPreambleID(void);
void Echo_SendData(void);
void Echo_SendMessage(void);
void Echo_SendIDRepeat(byte repeatCount);

void Echo_StrobeHigh(void);
void Echo_StrobeLow(void);
void Echo_StrobeTriState(void);

interrupt void Echo_TxTimer_Interrupt(void);
interrupt void Echo_RxSPI_Interrupt(void);


#if ECHO_BANK_A_EN == 1 && ECHO_BANK_B_EN == 0
  #if ECHO_MODE_VALUE == ECHO_OOK
  	#define Echo_SetFreq      Echo_SetFreqOok
  	#define Echo_SetFreqNoFRM Echo_SetFreqOokNoFRM
  #else
  	#define Echo_SetFreq      Echo_SetFreqFsk
  	#define Echo_SetFreqNoFRM Echo_SetFreqFskNoFRM
  #endif  
#endif

void Echo_SetFreqOok(unsigned int carrier);
void Echo_SetFreqOokNoFRM(unsigned int localOscillator, unsigned int carrier0);
void Echo_SetFreqFsk(unsigned int carrier, byte deltaF);
void Echo_SetFreqFskNoFRM(unsigned int localOscillator,
					   unsigned int carrier0,
					   unsigned int carrier1);

void Echo_Set_RxOnOff(byte on, byte off);
void Echo_EnableRSSI(void);
void Echo_DisableRSSI(void);

void Echo_SetRxSensitivity(byte level);
void Echo_SetTxPower(byte level);

void Echo_RagcHigh(void);
void Echo_RagcLow(void);
void Echo_FagcHigh(void);
void Echo_FagcLow(void);

void Echo_ChangeConfig(byte numReg,
					   byte startReg,
					   byte *regData,
					   byte readWrite
					   );
void Echo_ChangeBank(byte bank);					   


#endif //ECHO_H
