/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
\file       lle_GPIO.h
\brief      GPIO pin assignment corresponding to DZ60 daughter board.
\author     Freescale Semiconductor
\author     B05114
\version    0.1
\date       September/2007
*/
/*******************************************************************************/

#ifndef _LLE_GPIO_H
#define _LLE_GPIO_H

/** Derivative peripheral declarations */
#include "derivative.h"    

/* General purpose indicator LED */
#define LED1            PTCD_PTCD3      /* PTC3 */
#define PIN12           PTFD_PTFD4      /* PTF4 */
#define PIN13           PTFD_PTFD5      /* PTF5 */
#define PIN28           PTGD_PTGD5      /* PTG5 */

/* Interrupt switch */	    
#define	IRQ1	        PTAD_PTAD7      /* PTA1/IRQ */

/* GPIO-SPI used for APD devices */
#define	SCLK_MCU        PTFD_PTFD2      /* PTF2/TPM1CLK */
#define	MOSI_MCU        PTFD_PTFD3      /* PTF3 */
#define	MISO_MCU        PTGD_PTGD4      /* PTG4 */

/* Serial Peripheral Interface SPI1, used for ECHO transceiver*/
#define	SCLK_MC33696    PTED_PTED3      /* PTE3/ SPSCK */	
#define	MOSI_MC33696	PTED_PTED4      /* PTE4/ MOSI */
#define	MISO_MC33696	PTED_PTED5      /* PTE5/ MISO */  

/* Serial Communication Interface */
#define	RX_MAX202       PTED_PTED1      /* PTE1/RXD1 */	
#define	TX_MAX202       PTED_PTED0      /* PTE0/TXD1 */   


/* SBC: MC33742 pin assignment */
#define	CS_MC33742      PTGD_PTGD2      /* PTG2 */
#define	WDOG_MC33742    PTAD_PTAD4      /* PTA4 */	              
#define	INT_MC33742     PTBD_PTBD6      /* PTB6 */
#define	CAN3_RX         PTED_PTED6      /* PTE7/RXCAN */
#define	CAN3_TX         PTED_PTED6      /* PTE6/TXCAN */	    


/* MSDI I: MC33972 pin assignment */
#define	CS_MC33972_I    PTFD_PTFD6      /* PTF6 */
#define	CS_MC33972_II   CS_MC33972_I    /* MSDI II not present */
#define	INT_MC33972_I   PTAD_PTAD3      /* PTA3 */
#define	AMUX_MC33972_I  18              /* PTC2/ADP18 */


/* COSS: MC33879 pin assignment */
#define	CS_MC33879      PTAD_PTAD0      /* PTA0 */
#define	EN_MC33879      PTAD_PTAD6      /* PTA6 */
#define	PWM_IN6_MC33879 PTDD_PTDD4      /* PTD4 */
#define	PWM_IN5_MC33879 PTDD_PTDD3      /* PTD3 */


/* High Side Switch: MC10XS3412 */
#define	RST_MC10XS3412  PTFD_PTFD7      /* PTF7 */  
#define	CS_MC10XS3412   PTCD_PTCD1      /* PTC1 */
#define	IN0_MC10XS3412  PTDD_PTDD2      /* PTD2 */
#define	FS_MC10XS3412   PTBD_PTBD2      /* PTB2 */
#define	CSNS_MC10XS3412 PTCD_PTCD7      /* PTC7/ADP23 */


/* High Side Switch: MC15XS3400 */
#define	RST_MC15XS3400  PTDD_PTDD7      /* PTD7 */
#define	CS_MC15XS3400   PTBD_PTBD1      /* PTB1 */
#define	IN0_MC15XS3400  PTDD_PTDD6      /* PTD6 */
#define	FS_MC15XS3400   PTBD_PTBD3      /* PTB3 */
#define	CSNS_MC15XS3400 PTCD_PTCD6      /* PTC6/ADP22 */


/* High Side Switch: MC35XS3400 */
#define	RST_MC35XS3400  PTBD_PTBD0      /* PTB0 */
#define	CS_MC35XS3400   PTAD_PTAD1      /* PTA1 */
#define	IN0_MC35XS3400  PTDD_PTDD5      /* PTD5 */
#define	FS_MC35XS3400   PTAD_PTAD2      /* PTA2 */
#define	CSNS_MC35XS3400 PTBD_PTBD7      /* PTB7/ADP15 */


/* H-Bridge: MC33887 */
#define	D1_MC33887      PTED_PTED2      /* PTE2 */
#define	EN_MC33887      PTGD_PTGD3      /* PTG3 */
#define	FB_MC33887      PTCD_PTCD0      /* PTC0 */
#define	IN2_MC33887     PTDD_PTDD1      /* PTD1 */
#define	IN1_MC33887     PTDD_PTDD0      /* PTD0 */


/* LIN channel */
#define	LIN2_RX         PTFD_PTFD1      /* PTF1/RXD2 */
#define	LIN2_TX         PTFD_PTFD0      /* PTF0/TXD2 */
#define	LIN2_EN         PTCD_PTCD4      /* PTC4 */


/* ECHO transceiver */
#define	MODE_MC33696    PTAD_PTAD5      /* PTA5 */
#define	CONFB_MC33696   PTBD_PTBD5      /* PTB5 */
#define	CS_MC33696      PTBD_PTBD4      /* PTB4 */
#define	STROBE_MC33696  PTCD_PTCD5      /* PTC5 */



/** Function Prototypes */

/** GPIO settings */
void lle_SetupPINS(void);


#endif /* _LLE_GPIO_H */

/*******************************************************************************/