/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
Freescale Confidential Proprietary
\file       lle_TIME.h
\brief      Definitions and function prototypes for S08DZ60 timers
\author     Freescale Semiconductor
\author     B05114
\version    0.1
\date       September/2007
*/
/*******************************************************************************/

#ifndef _LLE_TIME_H
#define _LLE_TIME_H


#undef MCG_BLPE_MODE   /* Select Bypassed Low Power External mode */
#define  MCG_PEE_MODE    /* Select PLL engaged external mode */

/* For BLPE mode:
                Bus_Clock = (1/2)*(Oscillator_clock/Bus_divider)       */

/* FOR PEE mode:
Bus_Clock = (1/2)*[(Oscillator_clock/Reference_divider)*VCO_divider]/(Bus_divider) = 8MHz */
   
#define BUS_DIV 0       /* Bus divider = 0, divide by 1 */

#ifdef  MCG_PEE_MODE
#define REF_DIV 3       /* Reference divider = 3, divide by 8 */          
#define VCO_DIV 4       /* VCO divider = 4, multiply by 16 */
#endif


/* Constants for delays */
#define   DELAY_100uS   245         /* Wait ~100us, XOSC 8MHz */ 
#define   DELAY_4mS     10000       /* Wait ~4ms, XOSC 8MHz */
#define   DELAY_10mS    24700       /* Wait ~10ms, XOSC 8MHz */


/** Function Prototypes */

/** Multipurpose Clock Generator initialization */
void lle_MCG_Init(void);

/** Real time counter initialization at 50 ms */
void lle_Init_RTC(void);

/** Real time interrupt initialization at 150ms 
void lle_RTI_150ms(void);*/

/** 100 us software delay loop */		
void lle_Delay100us(void);

/** 4 ms software delay loop */	
void lle_Delay4ms(void);
	
/** 10 ms software delay loop */
void lle_Delay10ms(void);

#endif /* _LLE_TIME_H */

/*******************************************************************************/

