/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
Freescale Confidential Proprietary
\file       lle_ADC.c
\brief      Driver for basic S08DZ60 ADC operation
\author     Freescale Semiconductor
\author     B05114
\version    0.1
\date       September/2007
*/
/*******************************************************************************/

/** Derivative peripheral declarations */
#include "derivative.h"  

/** Common defines and macros */
#include <hidef.h>   

/** Variable types and common definitions */
#include "typedefs.h"  


/*******************************************************************************/
/**
* \brief    ADC initialization
* \author   B05114
* \param    void
* \return   void
*/
void lle_Init_ADC(void)
{
    APCTL3_ADPC18 = 1;      /* I/O control disables, channel AD18 enabled as analog input */
    
    ADCCFG_ADLPC = 0;       /* High speed configuration */    
    ADCCFG_ADLSMP = 1;      /* Long sample time */
    ADCCFG_MODE = 0x01;     /* 12 bit resolution */
    ADCCFG_ADIV = 0x01;     /* Divide ADC clock by 2 */
    ADCCFG_ADICLK = 0;      /* Bus clock (8MHz) selected, ADC internal clock = 4 MHz*/
    
    ADCSC2_ADTRG = 0;       /* Software trigger selected */
    
    ADCSC1_ADCO = 0;        /* One conversion software triggered */                
}

/*******************************************************************************/
/**
* \brief    ADC calibration
* \author   B05114
* \param    void
* \return   void
*/

void lle_Calibrate_ADC(void)
{
    
   
}    

/*******************************************************************************/
/**
* \brief    ADC single conversion SW trigger
* \author   B05114
* \param    const unsigned int chan
* \return   unsigned int 
*/
    
UINT16 lle_ADC(UINT8 u8ADC_chan)
{
    ADCSC1_ADCH = u8ADC_chan;   
    
        while(!ADCSC1_COCO);    /* Wait for end of conversion */        
    
    return ADCR;                /* Read ADCRH-ADRCL to clear COCO flag */
} 

/*******************************************************************************/
