/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
Freescale Confidential Proprietary
\file       lle_GPIO_SPI.c
\brief      GPIO based SPI driver for MC9S08DZ60
\author     Freescale Semiconductor
\author     B05114
\version    0.1
\date       September/2007
*/
/*******************************************************************************/

/** Derivative peripheral declarations */
//#include "derivative.h" 

/** Variable types and common macros */
#include "typedefs.h"

/** GPIO definitions and function prototypes */
#include "lle_GPIO.h"

/** SPI driver definitions and function prototypes */
#include "lle_GPIO_SPI.h"


UINT8 u8TxData;
UINT8 u8RxData;


/*******************************************************************************/
/**
* \brief    Initializing of GPIO based SPI
* \author   B05114
* \param    void 
* \return   void
*/
void lle_GPIO_SPI_Init(void)
{
    SCLK_MCU = 0;     /* SPI bus idle state */
    MOSI_MCU = 1; 
}

/*******************************************************************************/
/**
* \brief    8 bit transmission and reception through GPIO-based SPI
* \author   B05114
* \param    u8Data: size of the data array to be transmitted 
* \return   void (The received data is stored in the input array)
*/
UINT8 lle_GPIO_SPI(UINT8 u8Data)
{    
    UINT8 u8bit_count;
           
    u8TxData = u8Data;
    u8RxData = 0;
    
    SCLK_MCU = 0;     /* SPI bus idle state */
    MOSI_MCU = 1;   
    
        for(u8bit_count = 0; u8bit_count < 8; u8bit_count++)
        {
            SCLK_MCU = 1;    /* SCLK high */
                                    
            if(u8TxData & 0x80) 
                MOSI_MCU = 1;
            else
                MOSI_MCU = 0; 
                                                  
            u8TxData = u8TxData << 1;   /* Shift data */                                 
            u8RxData = u8RxData << 1;    
            
            SCLK_MCU = 0;   /* SCLK low */ 
            
            u8RxData |= MISO_MCU;        /* Read input pin */                                                         
        }
                
    SCLK_MCU = 0;     /* SPI bus idle state */
    MOSI_MCU = 1;   
        
    return u8RxData;    /* Store the read value */  
}

/*******************************************************************************/
/**
* \brief    8 bit transference through GPIO-based SPI
* \author   B05114
* \param    *ptSPI: Pointer to array with the data to be sent
* \return   void (The received data is stored in the input array)
*/

UINT8 lle_SPI_8(UINT8 *ptSPI)
{    
    ptSPI[0] = lle_GPIO_SPI(ptSPI[0]);  /* Send first byte in data array */ 
    return ptSPI[0];
}

/*******************************************************************************/
/**
* \brief    16 bit transference through GPIO-based SPI
* \author   B05114
* \param    *ptSPI: Pointer to array with the data to be sent
* \return   void (The received data is stored in the input array)
*/

void lle_SPI_16(UINT8 *ptSPI)
{   
    UINT8 u8byte_count;
       
        for (u8byte_count = 0; u8byte_count < 2; u8byte_count++)
        
            /* Send and receive two bytes */   
            ptSPI[u8byte_count] = lle_GPIO_SPI(ptSPI[u8byte_count]);                 
}

/*******************************************************************************/
/**
* \brief    24 bit transference through GPIO-based SPI
* \author   B05114
* \param    *ptSPI: Pointer to array with the data to be sent
* \return   void (The received data is stored in the input array)
*/

void lle_SPI_24(UINT8 *ptSPI)
{
    UINT8 u8byte_count;
       
        for (u8byte_count = 0; u8byte_count < 3; u8byte_count++)
        
            /* Send and receive three bytes */   
            ptSPI[u8byte_count] = lle_GPIO_SPI(ptSPI[u8byte_count]);             
}

/*******************************************************************************/
