/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
Freescale Confidential Proprietary
\file       lle_TIME.c
\brief      S08DZ60 time base initialization and SW delay loops
\author     Freescale Semiconductor
\author     B05114
\version    0.1
\date       September/2007
*/
/*******************************************************************************/

/** Derivative peripheral declarations */
#include "derivative.h" 

/** Variable types and common definitions */
#include "typedefs.h" 

/** Definitions and function prototypes for timers */
#include "lle_TIME.h"

/*******************************************************************************/
/**
* \brief    Multipurpose Clock Generator initialization.
* \author   B05114
* \param    void
* \return   void
*/
void lle_MCG_Init(void) 
{
    MCGC2_BDIV = BUS_DIV;   /* Bus divider */        
    MCGC2_RANGE = 1;        /* High frequency range selected */
    MCGC2_HGO = 1;          /* High gain for external oscillator */
    MCGC2_EREFS = 1;        /* External reference is crystal oscillator */ 
    MCGC2_ERCLKEN = 1;      /* External reference enabled */
    
        while(!MCGSC_OSCINIT);  /* Wait until the initialization cycles
                                   of the external oscillator are complete */
                                 
    MCGC1_CLKS = 0x02;      /* External reference is system clock source */
    MCGC1_RDIV = 0x07;      /* Configure Reference Divider to div by 128 */      
    MCGC1_IREFS = 0;        /* External reference clock selected */
                                      
        while(MCGSC_IREFST);  /* Wait until the external reference is 
                                 the source for the reference clock */   
                                 
        while((MCGSC_CLKST)^(0x02));  /* Wait until the external reference 
                                         is directed to MCGOUT */    
                                        
    MCGC2_LP = 1;           /* BLPE mode entered */  
         
         
#ifdef MCG_PEE_MODE

    MCGC1_RDIV = REF_DIV;   /* Configure the Reference Divider */
    MCGC3_PLLS = 1;         /* Enable PLL to use it in PBE mode */
    MCGC3_VDIV = VCO_DIV;   /* Multiplication factor applied to the reference */
    
        while(!MCGSC_PLLST);    /* Wait until the PLL is the 
                                   source for the reference clock */   
                                   
    MCGC2_LP = 0;   /* Switch to PBE mode before going to PEE mode */          
    
        while(!MCGSC_LOCK);    /* Wait until the PLL locks */     
        
    MCGC1_CLKS = 0x00;      /* PLL selected as system clock source */  
    
        while((MCGSC_CLKST)^(0x03));  /* Wait until the PLL is directed to MCGOUT */       
        
#endif                                                        
}


/*******************************************************************************/
/**
* \brief    Real time counter initialization at 25ms
* \author   B05114
* \param    void
* \return   void
*/
void lle_Init_RTC(void)
{   
    /* Real time clock source is external oscillator (8MHz)*/    
    RTCSC_RTCLKS = 0x01;  
    
    /* Prescaler set to divide by 2x10^5, RTI period = 25 ms */	
	RTCSC_RTCPS = 0x0F;     		
	RTCSC_RTIE = 1;     /* Real time interrupt enabled */       
}  

/*******************************************************************************/
/**
* \brief    100 us software delay loop
* \author   B02785
* \param    void
* \return   void
*/
void lle_Delay100us(void)
{ 
    UINT16 i;
           
    for(i=0; i<DELAY_100uS; i++ )   
        NOP();
}

/*******************************************************************************/
/**
* \brief    4 ms software delay loop
* \author   B02785
* \param    void
* \return   void
*/
void lle_Delay4ms(void)
{ 	
    UINT16 i;
     
    for(i=0; i<DELAY_4mS; i++ )       
        NOP();
}

/*******************************************************************************/
/**
* \brief    10 ms software delay loop
* \author   B02785
* \param    void
* \return   void
*/
void lle_Delay10ms(void)
{ 	
    UINT16 i;
	    
    for(i=0; i<DELAY_10mS; i++ )       
        NOP(); 
} 

/*******************************************************************************/