/*******************************************************************************/
/**
Copyright (c) 2007 Freescale Semiconductor
\file       main.c
\brief      Low end Body Control Unit (DZ60 daughter board second pass)
\author     Freescale Semiconductor
\author     B05114
\version    0.4
\date       October/2007
*/
/*******************************************************************************/
 
/** Derivative peripheral declarations */
#include "derivative.h" 

#include <hidef.h>

#include "main.h"

/** Variable types and common macros */
#include "typedefs.h"

#include <linapi.h>
#include "app_boardInit.h"
#include "app_boardAnalogVal.h"
#include "app_boardStatus.h"
#include "app_boardLoadCtrl.h"
#include "app_boardDevCtrl.h"
#include "app_boardDemoMode.h"
#include "app_RKE.h"

/** Definitions and function prototypes for LIN slave mirror controller */
#include "app_MirrorSlaveCtrl.h"

/** Definitions and function prototypes for LIN slave window-lift controller */
#include "app_WindowSlaveCtrl.h"


// Global timebase, reported status selector 
UINT8   PITflag;
UINT8   timebaseFlag;

// Control variables 
UINT8	fm_status, fm_task, fm_action0, fm_action1, fm_action2, fm_action3,
		fm_action4, fm_action5, fm_action6, fm_action7, fm_action8, fm_action9,
        fm_action10, fm_action11, fm_action12, fm_action13, fm_action14, fm_action15;

// Analog values variables              
UINT16	fm_analog1, fm_analog2, fm_analog3, fm_analog4, fm_analog5;


void LIN_Command(void);
interrupt void lle_RTC_Isr(void);

/*****************************************************************************/

void main( void )
{        		   
	app_initMCUPeriph();    /* Initialize MCU internal resources */  
		
	app_initAPDDevices();	/* Initial configuration for SBC, MSDI, 
	                        ESwitches, COSS, H-bridge, LIN transceiver*/
    
    ENABLE_INTERRUPTS();    /* Enable interrupts */   
    
    /* Execute sutonomous demo mode until some push-button is pressed */
    app_Autodemo_Mode();  
                        
    	         
    LIN_Init();       /* Initialize LIN driver */

    InitEcho();       /* Initialize ECHO driver */
     
     
	while(1)
	{    
		// 50ms period  
		if(PITflag == 1)
		{
		    PITflag = 0;
		                  		    
		    // Update system timebase
		    timebaseFlag++;
			if(timebaseFlag >= (PERIOD_3+1))
			{
				timebaseFlag = 1;
			}
		}
		
		// Select currently processed tasks based on the time schedule
		switch(timebaseFlag)
		{
			case PERIOD_1:
			{								
				app_boardStatus();  /* Read Devices status */
				
				/* Update MC33742 and eSwitches watchdogs */
				app_boardWatchdogUpd();
								
				/* Read analog values from stimulus board through MSDI */
				app_boardAnalogVal();
			
				/* Read through MSDI the push-buttons in stimulus board */				
                app_demoKeyboardState();    
			
				timebaseFlag++;	    /* Update system timebase */
				
				break;
			}
			
			
			case PERIOD_2:
			{	
			    app_DecRKEcommand();    /* Decode RKE command received */
			    
                timebaseFlag++;         /* Update system timebase */  
                                                                  
                break;
			}
			
			
			case PERIOD_3:			
			{									                    	
				app_boardLoadCtrl();    /* Control eSwitches, COSS, MSDI, H-bridge */
				
				app_Mirror_Control();   /* Send LIN command to mirror slave */
				
				app_Window_Control();   /* Send LIN command to window-lift slave */
																				
				timebaseFlag++;         /* Update system timebase */
				
				break;
			}			
		}			
	} 
} 

/*******************************************************************************/

void LIN_Command(void)
{
  /* endless loop */

  while(1);
}
/*****************************************************************************/
 
interrupt void lle_RTC_Isr( void )
{   
    PITflag = 1;        	
	RTCSC_RTIF = 1;     /* Clear RTC flag */
}

/*****************************************************************************/